@@ -1,14 +1,10 @@
 /*=========================================================================
 
   Program:   Advanced Normalization Tools
-  Module:    $RCSfile: AverageImages.cxx,v $
-  Language:  C++
-  Date:      $Date: 2009/01/27 23:25:24 $
-  Version:   $Revision: 1.21 $
 
   Copyright (c) ConsortiumOfANTS. All rights reserved.
   See accompanying COPYING.txt or
- http://sourceforge.net/projects/advants/files/ANTS/ANTSCopyright.txt for details.
+ https://github.com/stnava/ANTs/blob/master/ANTSCopyright.txt for details.
 
      This software is distributed WITHOUT ANY WARRANTY; without even
      the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -68,8 +64,8 @@ int AverageImages1(unsigned int argc, char *argv[])
   const bool  normalizei = atoi(argv[3]);
   const float numberofimages = (float)argc - 4.;
 
-  typename ImageType::SizeType size;
-  size.Fill(0);
+  typename ImageType::SizeType maxSize;
+  maxSize.Fill( 0 );
   unsigned int bigimage = 0;
   for( unsigned int j = 4; j < argc; j++ )
     {
@@ -79,17 +75,19 @@ int AverageImages1(unsigned int argc, char *argv[])
       itk::ImageIOFactory::CreateImageIO(fn.c_str(), itk::ImageIOFactory::ReadMode);
     imageIO->SetFileName(fn.c_str() );
     imageIO->ReadImageInformation();
-    for( unsigned int i = 0; i < imageIO->GetNumberOfDimensions(); i++ )
+
+    for( unsigned int i = 0; i < ImageType::ImageDimension; i++ )
       {
-      if( imageIO->GetDimensions(i) > size[i] )
+      itk::SizeValueType currentDimensionSize = imageIO->GetDimensions( i );
+
+      if( currentDimensionSize > maxSize[i] )
         {
-        size[i] = imageIO->GetDimensions(i);
+        maxSize[i] = currentDimensionSize;
         bigimage = j;
         }
       }
-    std::cout << " fn " << fn << std::endl;
-    std::cout << " bigimage " << bigimage << " curr_image " << j << " size " << size << std::endl;
     }
+  std::cout << " bigimage " << bigimage << " maxSize " << maxSize << std::endl;
 
   typename ImageFileReader::Pointer reader = ImageFileReader::New();
   reader->SetFileName(argv[bigimage]);
@@ -185,7 +183,10 @@ int AverageImages(unsigned int argc, char *argv[])
   typename ImageType::Pointer image2 = ITK_NULLPTR;
 
   typename ImageType::SizeType size;
-  size.Fill(0);
+  size.Fill( 0 );
+  typename ImageType::SizeType maxSize;
+  maxSize.Fill( 0 );
+
   unsigned int bigimage = 4;
   for( unsigned int j = 4; j < argc; j++ )
     {
@@ -196,11 +197,17 @@ int AverageImages(unsigned int argc, char *argv[])
       itk::ImageIOFactory::CreateImageIO(fn.c_str(), itk::ImageIOFactory::ReadMode);
     imageIO->SetFileName( fn.c_str() );
     imageIO->ReadImageInformation();
+
     for( unsigned int i = 0; i < imageIO->GetNumberOfDimensions(); i++ )
       {
-      if( imageIO->GetDimensions(i) > size[i] )
+      size[i] = imageIO->GetDimensions( i );
+      }
+
+    for( unsigned int i = 0; i < imageIO->GetNumberOfDimensions(); i++ )
+      {
+      if( size[i] > maxSize[i] )
         {
-        size[i] = imageIO->GetDimensions(i);
+        maxSize[i] = size[i];
         bigimage = j;
         std::cout << " bigimage " << j << " size " << size << std::endl;
         }
@@ -294,7 +301,7 @@ private:
 
   // antscout->set_stream( out_stream );
 
-  if( argc < 3 )
+  if( argc < 5 )
     {
     std::cout << "\n" << std::endl;
     std::cout << "Usage: \n" << std::endl;
@@ -333,12 +340,12 @@ private:
         {
         case 2:
           {
-          AverageImages<2, 2>(argc, argv);
+          return AverageImages<2, 2>(argc, argv);
           }
           break;
         default:
           {
-          AverageImages1<2, 1>(argc, argv);
+          return AverageImages1<2, 1>(argc, argv);
           }
           break;
         }
@@ -350,27 +357,27 @@ private:
         {
         case 7:
           {
-          AverageImages<3, 7>(argc, argv);
+          return AverageImages<3, 7>(argc, argv);
           }
           break;
         case 6:
           {
-          AverageImages<3, 6>(argc, argv);
+          return AverageImages<3, 6>(argc, argv);
           }
           break;
         case 3:
           {
-          AverageImages<3, 3>(argc, argv);
+          return AverageImages<3, 3>(argc, argv);
           }
           break;
         case 2:
           {
-          AverageImages<3, 2>(argc, argv);
+          return AverageImages<3, 2>(argc, argv);
           }
           break;
         default:
           {
-          AverageImages1<3, 1>(argc, argv);
+          return AverageImages1<3, 1>(argc, argv);
           }
           break;
         }
@@ -382,27 +389,27 @@ private:
         {
         case 7:
           {
-          AverageImages<4, 7>(argc, argv);
+          return AverageImages<4, 7>(argc, argv);
           }
           break;
         case 6:
           {
-          AverageImages<4, 6>(argc, argv);
+          return AverageImages<4, 6>(argc, argv);
           }
           break;
         case 4:
           {
-          AverageImages<4, 4>(argc, argv);
+          return AverageImages<4, 4>(argc, argv);
           }
           break;
         case 3:
           {
-          AverageImages<4, 3>(argc, argv);
+          return AverageImages<4, 3>(argc, argv);
           }
           break;
         default:
           {
-          AverageImages1<4, 1>(argc, argv);
+          return AverageImages1<4, 1>(argc, argv);
           }
           break;
         }
