@@ -1,14 +1,10 @@
 /*=========================================================================
 
   Program:   Advanced Normalization Tools
-  Module:    $RCSfile: ComputeSimilarityMetric.cxx,v $
-  Language:  C++
-  Date:      $Date: 2008/09/10 19:53:13 $
-  Version:   $Revision: 1.1 $
 
   Copyright (c) ConsortiumOfANTS. All rights reserved.
   See accompanying COPYING.txt or
- http://sourceforge.net/projects/advants/files/ANTS/ANTSCopyright.txt for
+ https://github.com/stnava/ANTs/blob/master/ANTSCopyright.txt for
 
      This software is distributed WITHOUT ANY WARRANTY; without even
      the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -208,7 +204,7 @@ int ComputeSimilarityMetric(int argc, char *argv[])
 */
     }
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
@@ -261,7 +257,7 @@ private:
     std::cout << "Basic useage ex: " << std::endl;
     std::cout << argv[0] << " ImageDimension whichmetric image1.ext image2.ext {logfile} {outimage.ext}  " << std::endl;
     std::cout << "  outimage and logfile are optional  " << std::endl;
-    return 1;
+    return EXIT_FAILURE;
     }
 
   // Get the image dimension
@@ -282,6 +278,6 @@ private:
       return EXIT_FAILURE;
     }
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 } // namespace ants
