@@ -1,10 +1,6 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: ConformalMapping.cxx,v $
-  Language:  C++
-  Date:      $Date: 2008/03/12 03:23:04 $
-  Version:   $Revision: 1.15 $
 
   Copyright (c) 2002 Insight Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
