@@ -22,7 +22,6 @@
 
 #include "vnl/vnl_matrix.h"
 #include "vnl/vnl_vector.h"
-#include "vcl_complex.h"
 
 #include <iomanip>
 
@@ -61,7 +60,7 @@ double CalculateFractionalAnisotropy( TensorType tensor )
     numerator += vnl_math_sqr( eigenvalues[d] - mean );
     denominator += vnl_math_sqr( eigenvalues[d] );
     }
-  fa = vcl_sqrt( ( 3.0 * numerator ) / ( 2.0 * denominator ) );
+  fa = std::sqrt( ( 3.0 * numerator ) / ( 2.0 * denominator ) );
 
   return fa;
 }
@@ -195,7 +194,7 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
       lowerThresholdFunction = parser->Convert<RealType>( maskImageOption->GetFunction( 0 )->GetName() );
       }
     }
-  if( !maskImage->GetBufferPointer() )
+  if( maskImage.IsNull() )
     {
     std::cout << "Mask not read.  Creating mask by thresholding "
              << "the FA of the DTI atlas at >= " << lowerThresholdFunction
@@ -452,7 +451,7 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
     decomposer->EvaluateSymmetricEigenDecomposition( MMt, Lambda, E );
 
     ISV = ( M.GetTranspose() * E.GetVnlMatrix() )
-      / vcl_sqrt( static_cast<float>( imageNames.size() ) );
+      / std::sqrt( static_cast<float>( imageNames.size() ) );
 
     applyISV = true;
     }
@@ -505,7 +504,7 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
       if( count % ImageDimension == 0 )
         {
         directions.push_back( direction );
-        if( dwiOption->GetFunction( 0 )->GetNumberOfParameters() < 2 )
+        if( dwiOption->GetFunction( 0 )->GetNumberOfParameters() < 3 )
           {
           str >> x;
           bvalues.push_back( x );
@@ -517,11 +516,23 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
         }
       }
 
-    if( numberOfDirections != directions.size() - 1 )
+    if( dwiOption->GetFunction( 0 )->GetNumberOfParameters() < 3 )
       {
-      std::cout << "ERROR:  Number of directions does not match the data file."
-               << std::endl;
-      return EXIT_FAILURE;
+      if( bvalues.size() != directions.size() )
+        {
+        std::cout << "ERROR:  Number of bvalues does not match the number of directions."
+                 << std::endl;
+        return EXIT_FAILURE;
+        }
+      }
+    else
+      {
+      if( numberOfDirections != directions.size() - 1 )
+        {
+        std::cout << "ERROR:  Number of directions does not match the data file."
+                 << std::endl;
+        return EXIT_FAILURE;
+        }
       }
     }
   else
@@ -562,7 +573,7 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
     if( n == 0 )
       {
       std::cout << "--- Calculating regional average FA and MD values (original and "
-               << "pathology) ---" << std::endl << std::endl;
+               << "pathology + intersubject variability) ---" << std::endl << std::endl;
       }
     else if( n <= numberOfControls )
       {
@@ -754,10 +765,10 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
       {
       std::cout << "   " << std::left << std::setw( 7 ) << "Region"
                << std::left << std::setw( 15 ) << "FA (original)"
-               << std::left << std::setw( 15 ) << "FA (pathology)"
+               << std::left << std::setw( 15 ) << "FA (path+isv)"
                << std::left << std::setw( 15 ) << "FA (% change)"
                << std::left << std::setw( 15 ) << "MD (original)"
-               << std::left << std::setw( 15 ) << "MD (pathology)"
+               << std::left << std::setw( 15 ) << "MD (path+isv)"
                << std::left << std::setw( 15 ) << "MD (% change)"
                << std::endl;
       for( unsigned int l = 1; l < labels.size(); l++ )
@@ -843,7 +854,7 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
 
           vnl_vector<RealType> bkD = bk * D;
 
-          RealType signal = ItB.Get() * vcl_exp( -bvalue * inner_product( bkD, bk ) );
+          RealType signal = ItB.Get() * std::exp( -bvalue * inner_product( bkD, bk ) );
 
           // Add Rician noise
           RealType realNoise = 0.0;
@@ -858,9 +869,9 @@ int CreateDTICohort( itk::ants::CommandLineParser *parser )
           RealType realSignal = signal + realNoise;
           RealType imagSignal = imagNoise;
 
-          vcl_complex<RealType> noisySignal( realSignal, imagSignal );
+          std::complex<RealType> noisySignal( realSignal, imagSignal );
 
-          RealType finalSignal = vcl_sqrt( vcl_norm( noisySignal ) );
+          RealType finalSignal = std::sqrt( std::norm( noisySignal ) );
 
           if( signal <= ItB.Get() )
             {
@@ -1181,12 +1192,12 @@ private:
     {
     case 2:
       {
-      CreateDTICohort<2>( parser );
+      return CreateDTICohort<2>( parser );
       }
       break;
     case 3:
       {
-      CreateDTICohort<3>( parser );
+      return CreateDTICohort<3>( parser );
       }
       break;
     default:
