@@ -23,7 +23,7 @@
 #include "itkGradientRecursiveGaussianImageFilter.h"
 #include "itkVectorCurvatureAnisotropicDiffusionImageFilter.h"
 
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 #include "itkSignedMaurerDistanceMapImageFilter.h"
 
 #include "itkGradientRecursiveGaussianImageFilter.h"
@@ -39,7 +39,6 @@ typename TImage::Pointer
 GetVectorComponent(typename TField::Pointer field, unsigned int index)
 {
   // Initialize the Moving to the displacement field
-  typedef TField FieldType;
   typedef TImage ImageType;
 
   typename ImageType::Pointer sfield = AllocImage<ImageType>(field);
@@ -62,7 +61,7 @@ MaurerDistanceMap(
   typename TImage::PixelType pixhi,
   typename TImage::Pointer input)
 {
-  // antscout << " DDMap " << std::endl;
+  // std::cout << " DDMap " << std::endl;
 
   typedef TImage ImageType;
 
@@ -145,7 +144,6 @@ template <class TImage, class TDisplacementField>
 typename TImage::Pointer
 CopyImage(TDisplacementField* field )
 {
-  typedef TImage ImageType;
   enum { ImageDimension = TImage::ImageDimension };
   //  unsigned int row=0;
   // unsigned int col=0;
@@ -153,7 +151,7 @@ CopyImage(TDisplacementField* field )
   typedef itk::Image<PixelType, ImageDimension> RealImageType;
   typename RealImageType::RegionType m_JacobianRegion;
 
-  typename RealImageType::Pointer m_RealImage = NULL;
+  typename RealImageType::Pointer m_RealImage = ITK_NULLPTR;
   m_RealImage = AllocImage<RealImageType>(field, 0);
 
   return m_RealImage;
@@ -164,7 +162,7 @@ typename TImage::Pointer
 LabelSurface(typename TImage::PixelType foreground,
              typename TImage::PixelType newval, typename TImage::Pointer input, double distthresh )
 {
-  antscout << " Label Surf " << std::endl;
+  std::cout << " Label Surf " << std::endl;
   typedef TImage ImageType;
   enum { ImageDimension = ImageType::ImageDimension };
   // ORIENTATION ALERT: Original code set origin & spacing from
@@ -182,7 +180,7 @@ LabelSurface(typename TImage::PixelType foreground,
 
   GHood.GoToBegin();
 
-//  antscout << " foreg " << (int) foreground;
+//  std::cout << " foreg " << (int) foreground;
   while( !GHood.IsAtEnd() )
     {
     typename TImage::PixelType p = GHood.GetCenterPixel();
@@ -327,8 +325,6 @@ template <class TImage, class TField>
 typename TField::Pointer
 DiReCTCompose(typename TField::Pointer velofield, typename TField::Pointer diffmap )
 {
-  typedef TImage                     ImageType;
-  typedef TField                     DisplacementFieldType;
   typedef typename TField::PixelType PixelType;
   typename TField::PixelType zero, disp;
   enum { ImageDimension = TImage::ImageDimension };
@@ -368,7 +364,6 @@ InvertField( typename TField::Pointer field,
 
   typedef typename DisplacementFieldType::PixelType                VectorType;
   typedef typename DisplacementFieldType::IndexType                IndexType;
-  typedef typename VectorType::ValueType                           ScalarType;
   typedef itk::ImageRegionIteratorWithIndex<DisplacementFieldType> Iterator;
 
   typedef itk::ANTSImageRegistrationOptimizer<ImageDimension, double> ROType;
@@ -498,7 +493,7 @@ InvertField( typename TField::Pointer field,
     inverseFieldIN->SetPixel(index, inverseField->GetPixel(index) );
     }
 
-  //    antscout <<" difmag " << difmag << ": its " << ct <<  " len " << m_MFR->MeasureDeformation(inverseField ) <<
+  //    std::cout <<" difmag " << difmag << ": its " << ct <<  " len " << m_MFR->MeasureDeformation(inverseField ) <<
   // std::endl;
 
   return;
@@ -552,17 +547,12 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
   //   useEuclidean = atoi(argv[argct]);
   //   }
   argct++;
-  antscout << " smooth " << smoothingsigma << " thp " << thickprior << " gs " << gradstep << std::endl;
+  std::cout << " smooth " << smoothingsigma << " thp " << thickprior << " gs " << gradstep << std::endl;
   typedef RealType                                                      PixelType;
   typedef itk::Vector<RealType, ImageDimension>                         VectorType;
   typedef itk::Image<VectorType, ImageDimension>                        DisplacementFieldType;
   typedef itk::Image<PixelType, ImageDimension>                         ImageType;
-  typedef itk::ImageFileReader<ImageType>                               readertype;
-  typedef itk::ImageFileWriter<ImageType>                               writertype;
   typedef typename  ImageType::IndexType                                IndexType;
-  typedef typename  ImageType::SizeType                                 SizeType;
-  typedef typename  ImageType::SpacingType                              SpacingType;
-  typedef itk::Image<VectorType, ImageDimension + 1>                    tvt;
   typedef itk::ANTSImageRegistrationOptimizer<ImageDimension, RealType> ROType;
   typename ROType::Pointer m_MFR = ROType::New();
 
@@ -573,7 +563,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
   typename ImageType::DirectionType omat = wm->GetDirection();
   typename ImageType::DirectionType fmat = wm->GetDirection();
   fmat.SetIdentity();
-  antscout << " Setting Identity Direction  " << fmat << std::endl;
+  std::cout << " Setting Identity Direction  " << fmat << std::endl;
   wm->SetDirection(fmat);
   typename ImageType::Pointer totalimage;
   ReadImage<ImageType>(totalimage, wfn.c_str() );
@@ -615,7 +605,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
   RealType distthresh = 1.5;
   typename ImageType::Pointer wmgrow = Morphological<ImageType>(wmb, 0, 1, 1);
   typename ImageType::Pointer bsurf = LabelSurface<ImageType>(1, 1, wmgrow, distthresh); // or wmb ?
-  typename ImageType::Pointer speedprior = NULL;
+  typename ImageType::Pointer speedprior = ITK_NULLPTR;
   WriteImage<ImageType>(bsurf, "surf.nii.gz");
   //    typename RealTypeImageType::Pointer distfromboundary =
   //  typename ImageType::Pointer surf=MaurerDistanceMap<ImageType>(0.5,1.e9,bsurf);
@@ -630,13 +620,8 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
 
   typedef   DisplacementFieldType
     TimeVaryingVelocityFieldType;
-  typedef itk::ImageRegionIteratorWithIndex<DisplacementFieldType>                          FieldIterator;
-  typedef typename DisplacementFieldType::IndexType                                         DIndexType;
   typedef typename DisplacementFieldType::PointType                                         DPointType;
-  typedef typename TimeVaryingVelocityFieldType::IndexType                                  VIndexType;
-  typedef typename TimeVaryingVelocityFieldType::PointType                                  VPointType;
   typedef itk::VectorLinearInterpolateImageFunction<TimeVaryingVelocityFieldType, RealType> DefaultInterpolatorType;
-  typedef itk::VectorLinearInterpolateImageFunction<DisplacementFieldType, RealType>        DefaultInterpolatorType2;
   typename DefaultInterpolatorType::Pointer vinterp =  DefaultInterpolatorType::New();
   vinterp->SetInputImage(lapgrad);
   typedef itk::LinearInterpolateImageFunction<ImageType, RealType> ScalarInterpolatorType;
@@ -670,7 +655,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
     }
 
   //  m_MFR->SmoothDisplacementFieldGauss(lapgrad,1.7);
-  antscout << " Scaling done " << std::endl;
+  std::cout << " Scaling done " << std::endl;
 
   typename ImageType::Pointer thickimage = laplacian;
   VectorType disp;
@@ -693,7 +678,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
     its++;
     if( totalerr > lasterr )
       {
-      badct++; antscout << " badct " << badct << std::endl;
+      badct++; std::cout << " badct " << badct << std::endl;
       }
     else
       {
@@ -718,13 +703,13 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
     thickerrct = 1;
     bool debug = false;
     bool spatprior = false;
-    typename ImageType::Pointer priorim = NULL;
+    typename ImageType::Pointer priorim = ITK_NULLPTR;
     if( speedprior )
       {
       spatprior = true;
       priorim = speedprior;
       }
-    typename ImageType::Pointer wpriorim = NULL;
+    typename ImageType::Pointer wpriorim = ITK_NULLPTR;
     RealType origthickprior = thickprior;
 
     while( ttiter < numtimepoints )    // N time integration points
@@ -734,14 +719,14 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
 
       if( debug )
         {
-        antscout << " exp " << std::endl;
+        std::cout << " exp " << std::endl;
         }
       // Integrate the negative velocity field to generate diffeomorphism corrfield step 3(a)
       //      corrfield=ExpDiffMap<ImageType,DisplacementFieldType>( velofield,  wm, -1, numtimepoints-ttiter);
-      //      antscout  << " corrf len " << m_MFR->MeasureDeformation( corrfield ) << std::endl;
+      //      std::cout  << " corrf len " << m_MFR->MeasureDeformation( corrfield ) << std::endl;
       if( debug )
         {
-        antscout << " gmdef " << std::endl;
+        std::cout << " gmdef " << std::endl;
         }
       typename ImageType::Pointer gmdef = gm; // m_MFR->WarpImageBackward(gm,corrfield);
       totalerr = 0;
@@ -749,12 +734,12 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
       typename ImageType::Pointer surfdef = m_MFR->WarpImageBackward(wm, invfield);
       if( debug )
         {
-        antscout << " thkdef " << std::endl;
+        std::cout << " thkdef " << std::endl;
         }
       typename ImageType::Pointer thkdef = m_MFR->WarpImageBackward(thickimage, invfield);
       if( debug )
         {
-        antscout << " thindef " << std::endl;
+        std::cout << " thindef " << std::endl;
         }
       typename ImageType::Pointer thindef = m_MFR->WarpImageBackward(bsurf, invfield);
       if( spatprior )
@@ -859,7 +844,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
           }
         }
       /* Now that we have the gradient image, we need to visit each voxel and compute objective function */
-      //      antscout << " maxlapgrad2mag " << maxlapgrad2mag << std::endl;
+      //      std::cout << " maxlapgrad2mag " << maxlapgrad2mag << std::endl;
       Iterator.GoToBegin();
       while(  !Iterator.IsAtEnd()  )
         {
@@ -960,7 +945,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
         }
       if( thkval > 10 )
         {
-        antscout << "thkval " << thkval << " hitval " << hitval << " total " << totalimage->GetPixel(velind)
+        std::cout << "thkval " << thkval << " hitval " << hitval << " total " << totalimage->GetPixel(velind)
                  << std::endl;
         }
       if( thkval < 0 )
@@ -988,7 +973,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
 
     if( debug )
       {
-      antscout << " now smooth " << std::endl;
+      std::cout << " now smooth " << std::endl;
       }
     m_MFR->SmoothDisplacementFieldGauss(velofield, smoothingsigma);
     WriteImage<DisplacementFieldType>(corrfield, "corrfield.nii.gz");
@@ -1007,7 +992,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
       {
       thickerrct = 1;
       }
-    antscout << " error " << totalerr << " at it " << its  << " th-err " << thicknesserror / (RealType)thickerrct
+    std::cout << " error " << totalerr << " at it " << its  << " th-err " << thicknesserror / (RealType)thickerrct
              << " max thick " << maxth << std::endl;
 //    std::string sulcthickname =outname + "sulcthick.nii";
     //    if (ImageDimension==2) WriteJpg<ImageType>(finalthickimage,"thick.jpg");
@@ -1015,7 +1000,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
     // WriteDisplacementField<DisplacementFieldType>(velofield,velofieldname.c_str());
     if( debug )
       {
-      antscout << "outside it " << its << std::endl;
+      std::cout << "outside it " << its << std::endl;
       }
     // std::cin.get();
     }
@@ -1050,7 +1035,7 @@ int LaplacianThicknessExpDiff2(int argc, char *argv[])
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
 // 'main()'
-int KellySlater( std::vector<std::string> args, std::ostream* out_stream = NULL )
+int KellySlater( std::vector<std::string> args, std::ostream* /*out_stream = NULL */ )
 {
   // put the arguments coming in as 'args' into standard (argc,argv) format;
   // 'args' doesn't have the command name as first, argument, so add it manually;
@@ -1068,7 +1053,7 @@ int KellySlater( std::vector<std::string> args, std::ostream* out_stream = NULL
     // place the null character in the end
     argv[i][args[i].length()] = '\0';
     }
-  argv[argc] = 0;
+  argv[argc] = ITK_NULLPTR;
   // class to automatically cleanup argv upon destruction
   class Cleanup_argv
   {
@@ -1092,16 +1077,16 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
 
   if( argc < 6 )
     {
-    antscout << "Usage:   " << argv[0]
+    std::cout << "Usage:   " << argv[0]
              <<
       " ImageDimension Segmentation.nii.gz WMProb.nii.gz GMProb.nii.gz   Out.nii {GradStep-1-2D,2-3D}   {#Its-~50}  {ThickPriorValue-6} {Bool-use-curvature-prior} {smoothing} {BoolUseEuclidean?}"
              << std::endl;
-    antscout << " this is a kind of binary image registration thing with diffeomorphisms " << std::endl;
-    antscout
+    std::cout << " this is a kind of binary image registration thing with diffeomorphisms " << std::endl;
+    std::cout
       << " Segmentation.nii.gz -- should contain the value 3 where WM exists and the value 2 where GM exists "
       << std::endl;
     if( argc >= 2 &&
@@ -1113,7 +1098,7 @@ private:
     }
 
   unsigned int dim = atoi(argv[1]);
-  antscout << " dim " << dim << std::endl;
+  std::cout << " dim " << dim << std::endl;
 
   switch( dim )
     {
@@ -1128,7 +1113,7 @@ private:
       }
       break;
     default:
-      antscout << "Unsupported dimension" << std::endl;
+      std::cout << "Unsupported dimension" << std::endl;
       return EXIT_FAILURE;
     }
   return EXIT_SUCCESS;
