@@ -1,14 +1,10 @@
 /*=========================================================================
 
   Program:   Advanced Normalization Tools
-  Module:    $RCSfile: MultiplyImages.cxx,v $
-  Language:  C++
-  Date:      $Date: 2008/11/15 23:46:06 $
-  Version:   $Revision: 1.18 $
 
   Copyright (c) ConsortiumOfANTS. All rights reserved.
   See accompanying COPYING.txt or
- http://sourceforge.net/projects/advants/files/ANTS/ANTSCopyright.txt for details.
+ https://github.com/stnava/ANTs/blob/master/ANTSCopyright.txt for details.
 
      This software is distributed WITHOUT ANY WARRANTY; without even
      the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -75,10 +71,10 @@ int MultiplyImages(int argc, char *argv[])
     }
   catch( ... )
     {
-    std::cout << " Rather than opening " << fn2
-             <<
-      " as an image file, this program has decided, in its great wisdom, to consider it to be a floating point numerical value, and has acted accordingly -- i.e. read this as a number. "
-             << std::endl;
+//    std::cout << " Rather than opening " << fn2
+//             <<
+//      " as an image file, this program has decided, in its great wisdom, to consider it to be a floating point numerical value, and has acted accordingly -- i.e. read this as a number. "
+//             << std::endl;
     isfloat = true;
     }
 
@@ -124,7 +120,7 @@ int MultiplyImages(int argc, char *argv[])
   writer->SetInput( varimage );
   writer->Write();
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
@@ -177,6 +173,8 @@ private:
     {
     std::cout << "Usage:  " << std::endl;
     std::cout << argv[0] << " ImageDimension img1.nii img2.nii product.nii {smoothing}" << std::endl;
+    std::cout <<     " 2nd image file may also be floating point numerical value, and program will act accordingly -- i.e. read as a number. " << std::endl;
+    std::cout << " Program handles vector and tensor images as well " << std::endl;
     if( argc >= 2 &&
         ( std::string( argv[1] ) == std::string("--help") || std::string( argv[1] ) == std::string("-h") ) )
       {
@@ -192,6 +190,8 @@ private:
   imageIO->ReadImageInformation();
   unsigned int ncomponents = imageIO->GetNumberOfComponents();
 
+  int returnValue = EXIT_FAILURE;
+  
   // Get the image dimension
   switch( atoi(argv[1]) )
     {
@@ -201,17 +201,17 @@ private:
         {
         case 3:
           {
-          MultiplyImages<1, 3>(argc, argv);
+          returnValue = MultiplyImages<1, 3>(argc, argv);
           }
           break;
         case 2:
           {
-          MultiplyImages<1, 2>(argc, argv);
+          returnValue = MultiplyImages<1, 2>(argc, argv);
           }
           break;
         default:
           {
-          MultiplyImages<1, 1>(argc, argv);
+          returnValue = MultiplyImages<1, 1>(argc, argv);
           }
           break;
         }
@@ -223,17 +223,17 @@ private:
         {
         case 3:
           {
-          MultiplyImages<2, 3>(argc, argv);
+          returnValue = MultiplyImages<2, 3>(argc, argv);
           }
           break;
         case 2:
           {
-          MultiplyImages<2, 2>(argc, argv);
+          returnValue = MultiplyImages<2, 2>(argc, argv);
           }
           break;
         default:
           {
-          MultiplyImages<2, 1>(argc, argv);
+          returnValue = MultiplyImages<2, 1>(argc, argv);
           }
           break;
         }
@@ -245,22 +245,22 @@ private:
         {
         case 7:
           {
-          MultiplyImages<3, 7>(argc, argv);
+          returnValue = MultiplyImages<3, 7>(argc, argv);
           }
           break;
         case 6:
           {
-          MultiplyImages<3, 6>(argc, argv);
+          returnValue = MultiplyImages<3, 6>(argc, argv);
           }
           break;
         case 3:
           {
-          MultiplyImages<3, 3>(argc, argv);
+          returnValue = MultiplyImages<3, 3>(argc, argv);
           }
           break;
         default:
           {
-          MultiplyImages<3, 1>(argc, argv);
+          returnValue = MultiplyImages<3, 1>(argc, argv);
           }
           break;
         }
@@ -272,32 +272,32 @@ private:
         {
         case 7:
           {
-          MultiplyImages<4, 7>(argc, argv);
+          returnValue = MultiplyImages<4, 7>(argc, argv);
           }
           break;
         case 6:
           {
-          MultiplyImages<4, 6>(argc, argv);
+          returnValue = MultiplyImages<4, 6>(argc, argv);
           }
           break;
         case 4:
           {
-          MultiplyImages<4, 4>(argc, argv);
+          returnValue = MultiplyImages<4, 4>(argc, argv);
           }
           break;
         case 3:
           {
-          MultiplyImages<4, 3>(argc, argv);
+          returnValue = MultiplyImages<4, 3>(argc, argv);
           }
           break;
         case 2:
           {
-          MultiplyImages<4, 2>(argc, argv);
+          returnValue = MultiplyImages<4, 2>(argc, argv);
           }
           break;
         default:
           {
-          MultiplyImages<4, 1>(argc, argv);
+          returnValue = MultiplyImages<4, 1>(argc, argv);
           }
           break;
         }
@@ -308,6 +308,6 @@ private:
       return EXIT_FAILURE;
     }
 
-  return EXIT_SUCCESS;
+  return returnValue;
 }
 } // namespace ants
