@@ -1,14 +1,10 @@
 /*=========================================================================1
 
   Program:   Advanced Normalization Tools
-  Module:    $RCSfile: ReorientTensorImage.cxx,v $
-  Language:  C++
-  Date:      $Date: 2009/03/17 18:55:26 $
-  Version:   $Revision: 1.2 $
 
   Copyright (c) ConsortiumOfANTS. All rights reserved.
   See accompanying COPYING.txt or
- http://sourceforge.net/projects/advants/files/ANTS/ANTSCopyright.txt for details.
+ https://github.com/stnava/ANTs/blob/master/ANTSCopyright.txt for details.
 
      This software is distributed WITHOUT ANY WARRANTY; without even
      the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
