@@ -88,6 +88,9 @@ int ResampleImage( int argc, char *argv[] )
   typename ResamplerType::Pointer resampler = ResamplerType::New();
   typename ResamplerType::SpacingType spacing;
   typename ResamplerType::SizeType size;
+  typename ImageType::IndexType oldStartIndex = image->GetLargestPossibleRegion().GetIndex();
+typename ImageType::IndexType newStartIndex;
+  newStartIndex.Fill(0); // should be "same" as original start index but in new physical space
 
   std::vector<RealType> sp = ConvertVector<RealType>( std::string( argv[4] ) );
 
@@ -113,6 +116,8 @@ int ResampleImage( int argc, char *argv[] )
       RealType spacing_old = image->GetSpacing()[i];
       RealType size_old = image->GetLargestPossibleRegion().GetSize()[i];
       size[i] = static_cast<int>( ( spacing_old * size_old ) / spacing[i] + 0.5 );
+      RealType oldstart = static_cast<float>( oldStartIndex[i] );
+      newStartIndex[i] = static_cast<int>( ( spacing_old * oldstart ) / spacing[i] + 0.5 );
       }
     }
   else
@@ -136,8 +141,11 @@ int ResampleImage( int argc, char *argv[] )
       {
       RealType spacing_old = image->GetSpacing()[i];
       RealType size_old = image->GetLargestPossibleRegion().GetSize()[i];
-      spacing[i] = spacing_old * static_cast<float>( size_old - 1.0 )
-        / static_cast<float>( size[i] - 1.0 );
+      float ratio = static_cast<float>( size_old - 1.0 )
+                  / static_cast<float>( size[i] - 1.0 );
+      spacing[i] = spacing_old * ratio;
+      RealType oldstart = static_cast<float>( oldStartIndex[i] );
+      newStartIndex[i] = static_cast<int>( oldstart * ratio + 0.5 );
       }
     }
 
@@ -240,10 +248,14 @@ int ResampleImage( int argc, char *argv[] )
   resampler->SetOutputOrigin( image->GetOrigin() );
   resampler->SetOutputDirection( image->GetDirection() );
   resampler->SetOutputSpacing( spacing );
+//  resampler->SetOutputStartIndex( newStartIndex );
   resampler->SetDefaultPixelValue( 0 );
   resampler->Update();
-
-  WriteImage<ImageType>( resampler->GetOutput() , argv[3] );
+  typename ImageType::Pointer outimage = resampler->GetOutput();
+//  typename ImageType::RegionType region = outimage->GetLargestPossibleRegion();
+//  region.SetIndex( newStartIndex );
+//  outimage->SetLargestPossibleRegion( region );
+  WriteImage<ImageType>( outimage , argv[3] );
   return EXIT_SUCCESS;
 }
 
@@ -315,17 +327,17 @@ private:
     {
     case 2:
       {
-      ResampleImage<2>( argc, argv );
+      return ResampleImage<2>( argc, argv );
       }
       break;
     case 3:
       {
-      ResampleImage<3>( argc, argv );
+      return ResampleImage<3>( argc, argv );
       }
       break;
     case 4:
       {
-      ResampleImage<4>( argc, argv );
+      return ResampleImage<4>( argc, argv );
       }
       break;
     default:
