@@ -8,14 +8,10 @@
 /*=========================================================================
 
   Program:   Advanced Normalization Tools
-  Module:    $RCSfile: SetSpacing.cxx,v $
-  Language:  C++
-  Date:      $Date: 2009/03/06 03:57:48 $
-  Version:   $Revision: 1.1 $
 
   Copyright (c) ConsortiumOfANTS. All rights reserved.
   See accompanying COPYING.txt or
- http://sourceforge.net/projects/advants/files/ANTS/ANTSCopyright.txt for details.
+ https://github.com/stnava/ANTs/blob/master/ANTSCopyright.txt for details.
 
      This software is distributed WITHOUT ANY WARRANTY; without even
      the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -152,12 +148,12 @@ private:
     {
     case 2:
       {
-      SetSpacing<2>(argc - 1, argv + 1);
+      return SetSpacing<2>(argc - 1, argv + 1);
       }
       break;
     case 3:
       {
-      SetSpacing<3>(argc - 1, argv + 1);
+      return SetSpacing<3>(argc - 1, argv + 1);
       }
       break;
     default:
