@@ -13,7 +13,7 @@
 #include <math.h>
 #include <float.h>
 #include <assert.h>
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 
 #include <vnl/algo/vnl_symmetric_eigensystem.h>
 
@@ -58,7 +58,7 @@ int smallerStatElem(StatElement * elem1, StatElement * elem2)
 template <class TImageType>
 void ReadImage(itk::SmartPointer<TImageType> & target, const char *file, bool copy)
 {
-  //  antscout << " reading b " << std::string(file) << std::endl;
+  //  std::cout << " reading b " << std::string(file) << std::endl;
   typedef itk::ImageFileReader<TImageType> readertype;
   typename readertype::Pointer reader = readertype::New();
   reader->SetFileName(file);
@@ -380,7 +380,7 @@ double TTest(int numSubjects,   int* groupLabel, double * featureValue )
       }
     else
       {
-      antscout << " group label " << groupLabel[subj] << " does not exist" << std::endl;
+      std::cout << " group label " << groupLabel[subj] << " does not exist" << std::endl;
       }
     }
   meanA /= (float)numSubjA;
@@ -450,7 +450,7 @@ int StudentsTestOnImages(int argc, char *argv[])
     feature[i] = 0;
     }
 
-  antscout << " Numvals " << numvals << std::endl;
+  std::cout << " Numvals " << numvals << std::endl;
   // Get the image dimension
   std::string               fn = std::string(argv[5]);
   itk::ImageIOBase::Pointer imageIO =
@@ -467,7 +467,7 @@ int StudentsTestOnImages(int argc, char *argv[])
     size[i] = imageIO->GetDimensions(i);
 //       if (size[i] !=  mask->GetLargestPossibleRegion().GetSize()[i])
     // {
-    //  antscout <<  " mask not same size as data !! " << std::endl;
+    //  std::cout <<  " mask not same size as data !! " << std::endl;
     //  throw std::exception();
     // }
 
@@ -486,7 +486,7 @@ int StudentsTestOnImages(int argc, char *argv[])
         }
       }
     }
-  antscout << " size " << size << std::endl;
+  std::cout << " size " << size << std::endl;
   typename ImageType::RegionType region;
   region.SetSize(size );
   // ORIENTATION ALERT. the code this replaced originally didn't
@@ -511,7 +511,7 @@ int StudentsTestOnImages(int argc, char *argv[])
   for( unsigned int j = 0; j < numvals; j++ )
     {
     std::string ifn = std::string(argv[5 + j]);
-    antscout << "reading " << ifn << std::endl;
+    std::cout << "reading " << ifn << std::endl;
     ReadImage<ImageType>(imagestack[j], ifn.c_str(), false);
     }
 
@@ -525,7 +525,7 @@ int StudentsTestOnImages(int argc, char *argv[])
 
   unsigned long ct = 0;
   unsigned long prog = nvox / 20;
-  antscout << " NVals " << numvals << " NSub " << numSubjects <<  std::endl;
+  std::cout << " NVals " << numvals << " NSub " << numSubjects <<  std::endl;
   for(  vfIter.GoToBegin(); !vfIter.IsAtEnd(); ++vfIter )
     {
     typename ImageType::IndexType index = vfIter.GetIndex();
@@ -535,7 +535,7 @@ int StudentsTestOnImages(int argc, char *argv[])
       }
     if( ct % prog == 0 )
       {
-      antscout << " % " << (float) ct / (float) nvox << std::endl;
+      std::cout << " % " << (float) ct / (float) nvox << std::endl;
       }
 
     double stat = 0;
@@ -603,33 +603,33 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
 
-  antscout <<  " df     P = 0.05  P = 0.01   P = 0.001  " << std::endl;
-  antscout << " 1             12.71     63.66     636.61  " << std::endl;
-  antscout << " 2    4.30     9.92     31.60    " << std::endl;
-  antscout << " 3    3.18     5.84     12.92" << std::endl;
-  antscout << " 4    2.78     4.60     8.61" << std::endl;
-  antscout << " 5    2.57     4.03     6.87" << std::endl;
-  antscout << " 6     2.45     3.71     5.96" << std::endl;
-  antscout << " 7    2.36     3.50     5.41" << std::endl;
-  antscout << " 8    2.31     3.36     5.04" << std::endl;
-  antscout << " 9    2.26     3.25     4.78" << std::endl;
-  antscout << " 10    2.23     3.17     4.59" << std::endl;
-  antscout << " 15    2.13     2.95     4.07" << std::endl;
-  antscout << " 20    2.09     2.85     3.85" << std::endl;
-  antscout << " 30    2.04     2.75     3.65" << std::endl;
-  antscout << " 50    2.01     2.68     3.50" << std::endl;
-  antscout << " 100    1.98     2.63     3.39  " << std::endl;
+  std::cout <<  " df     P = 0.05  P = 0.01   P = 0.001  " << std::endl;
+  std::cout << " 1             12.71     63.66     636.61  " << std::endl;
+  std::cout << " 2    4.30     9.92     31.60    " << std::endl;
+  std::cout << " 3    3.18     5.84     12.92" << std::endl;
+  std::cout << " 4    2.78     4.60     8.61" << std::endl;
+  std::cout << " 5    2.57     4.03     6.87" << std::endl;
+  std::cout << " 6     2.45     3.71     5.96" << std::endl;
+  std::cout << " 7    2.36     3.50     5.41" << std::endl;
+  std::cout << " 8    2.31     3.36     5.04" << std::endl;
+  std::cout << " 9    2.26     3.25     4.78" << std::endl;
+  std::cout << " 10    2.23     3.17     4.59" << std::endl;
+  std::cout << " 15    2.13     2.95     4.07" << std::endl;
+  std::cout << " 20    2.09     2.85     3.85" << std::endl;
+  std::cout << " 30    2.04     2.75     3.65" << std::endl;
+  std::cout << " 50    2.01     2.68     3.50" << std::endl;
+  std::cout << " 100    1.98     2.63     3.39  " << std::endl;
 
   if( argc < 6 )
     {
-    antscout << "Usage: " << argv[0] <<  " ImageDimension  OutName NGroup1 NGroup2 ControlV1*   SubjectV1*   "
+    std::cout << "Usage: " << argv[0] <<  " ImageDimension  OutName NGroup1 NGroup2 ControlV1*   SubjectV1*   "
              << std::endl;
-    antscout << " Assume all images the same size " << std::endl;
-    antscout << " Writes out an F-Statistic image " << std::endl;
-    antscout <<  " \n example call \n  \n ";
-    antscout << argv[0] << "  2  TEST.nii.gz 4 8 FawtJandADCcon/*SUB.nii  FawtJandADCsub/*SUB.nii  \n ";
+    std::cout << " Assume all images the same size " << std::endl;
+    std::cout << " Writes out an F-Statistic image " << std::endl;
+    std::cout <<  " \n example call \n  \n ";
+    std::cout << argv[0] << "  2  TEST.nii.gz 4 8 FawtJandADCcon/*SUB.nii  FawtJandADCsub/*SUB.nii  \n ";
     return 1;
     }
 
@@ -646,7 +646,7 @@ private:
       }
       break;
     default:
-      antscout << "Unsupported dimension" << std::endl;
+      std::cout << "Unsupported dimension" << std::endl;
       return EXIT_FAILURE;
     }
 
