@@ -10,7 +10,7 @@
 #include "itkWarpTensorImageMultiTransformFilter.h"
 #include "itkTransformFileReader.h"
 #include "itkVectorNearestNeighborInterpolateImageFunction.h"
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 #include "itkWarpImageMultiTransformFilter.h"
 #include "itkExpTensorImageFilter.h"
 
@@ -23,7 +23,7 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
   opt_queue.clear();
   opt_queue.reserve(argc - 2);
 
-  misc_opt.reference_image_filename = NULL;
+  misc_opt.reference_image_filename = ITK_NULLPTR;
   misc_opt.use_NN_interpolator = false;
   misc_opt.use_TightestBoundingBox = false;
   misc_opt.use_RotationHeader = false;
@@ -79,9 +79,9 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
       }
     else if( strcmp(argv[ind], "--reference-image-header") == 0 || strcmp(argv[ind], "-rh") == 0 )
       {
-      if( misc_opt.reference_image_filename == NULL )
+      if( misc_opt.reference_image_filename == ITK_NULLPTR )
         {
-        antscout
+        std::cout
           << "reference image filename is not given yet. Specify it with -R before --reference-image-header / -rh."
           << std::endl;
         return false;
@@ -120,7 +120,7 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
         opt.file_type = CheckFileType(opt.filename.c_str() );
         opt.do_affine_inv = false;
         opt_queue.push_back(opt);
-        antscout << "found deformation file: " << opt.filename << std::endl;
+        std::cout << "found deformation file: " << opt.filename << std::endl;
         DisplayOpt(opt);
         }
 
@@ -133,7 +133,7 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
         opt.file_type = CheckFileType(opt.filename.c_str() );
         opt.do_affine_inv = false;
         opt_queue.push_back(opt);
-        antscout << "found affine file: " << opt.filename << std::endl;
+        std::cout << "found affine file: " << opt.filename << std::endl;
         DisplayOpt(opt);
         }
       }
@@ -157,7 +157,7 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
         opt.file_type = CheckFileType(opt.filename.c_str() );
         opt.do_affine_inv = true;
         opt_queue.push_back(opt);
-        antscout << "found affine file: " << opt.filename << std::endl;
+        std::cout << "found affine file: " << opt.filename << std::endl;
         DisplayOpt(opt);
         }
 
@@ -171,7 +171,7 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
         opt.file_type = CheckFileType(opt.filename.c_str() );
         opt.do_affine_inv = false;
         opt_queue.push_back(opt);
-        antscout << "found deformation file: " << opt.filename << std::endl;
+        std::cout << "found deformation file: " << opt.filename << std::endl;
         DisplayOpt(opt);
         }
       }
@@ -187,8 +187,8 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
         }
       else if( opt.file_type == DEFORMATION_FILE && set_current_affine_inv )
         {
-        antscout << "Ignore inversion of non-affine file type! " << std::endl;
-        antscout << "opt.do_affine_inv:" << opt.do_affine_inv << std::endl;
+        std::cout << "Ignore inversion of non-affine file type! " << std::endl;
+        std::cout << "opt.do_affine_inv:" << opt.do_affine_inv << std::endl;
         }
 
       opt_queue.push_back(opt);
@@ -213,7 +213,7 @@ static bool WarpTensorImageMultiTransform_ParseInput(int argc, char * *argv, cha
     //               opt.do_affine_inv = true;
     //               opt_queue.push_back(opt);
     //
-    //               antscout << "Use Rotation Header!" << std::endl;
+    //               std::cout << "Use Rotation Header!" << std::endl;
     }
 
   return true;
@@ -338,7 +338,7 @@ static void WarpImageMultiTransform(char *moving_image_filename, char *output_im
                                                                     typename WarperType::CoordRepType>
         NNInterpolateType;
       typename NNInterpolateType::Pointer interpolator_NN = NNInterpolateType::New();
-      antscout << "Haha" << std::endl;
+      std::cout << "Haha" << std::endl;
       warper->SetInterpolator(interpolator_NN);
       }
 
@@ -366,7 +366,7 @@ static void WarpImageMultiTransform(char *moving_image_filename, char *output_im
             aff->GetInverse(aff_inv);
             aff = aff_inv;
             }
-          // antscout <<" aff " << transcount <<  std::endl;
+          // std::cout <<" aff " << transcount <<  std::endl;
           warper->PushBackAffineTransform(aff);
           if( transcount == 0 )
             {
@@ -379,7 +379,7 @@ static void WarpImageMultiTransform(char *moving_image_filename, char *output_im
           {
           typename AffineTransformType::Pointer aff;
           GetIdentityTransform<AffineTransformType>(aff);
-          // antscout << " aff id" << transcount << std::endl;
+          // std::cout << " aff id" << transcount << std::endl;
           warper->PushBackAffineTransform(aff);
           transcount++;
           }
@@ -401,7 +401,7 @@ static void WarpImageMultiTransform(char *moving_image_filename, char *output_im
             aff = aff_inv;
             }
 
-          // antscout <<" aff from image header " << transcount <<  std::endl;
+          // std::cout <<" aff from image header " << transcount <<  std::endl;
           warper->PushBackAffineTransform(aff);
 
           //            if (transcount==0){
@@ -424,7 +424,7 @@ static void WarpImageMultiTransform(char *moving_image_filename, char *output_im
           break;
         default:
           {
-          antscout << "Unknown file type!" << std::endl;
+          std::cout << "Unknown file type!" << std::endl;
           }
         }
       }
@@ -455,10 +455,10 @@ static void WarpImageMultiTransform(char *moving_image_filename, char *output_im
         }
       }
 
-    // antscout << "output origin: " << warper->GetOutputOrigin() << std::endl;
-    // antscout << "output size: " << warper->GetOutputSize() << std::endl;
-    // antscout << "output spacing: " << warper->GetOutputSpacing() << std::endl;
-    //    antscout << "output direction: " << warper->GetOutputDirection() << std::endl;
+    // std::cout << "output origin: " << warper->GetOutputOrigin() << std::endl;
+    // std::cout << "output size: " << warper->GetOutputSize() << std::endl;
+    // std::cout << "output spacing: " << warper->GetOutputSpacing() << std::endl;
+    //    std::cout << "output direction: " << warper->GetOutputDirection() << std::endl;
 
     // warper->PrintTransformList();
     warper->DetermineFirstDeformNoInterp();
@@ -481,7 +481,7 @@ static void WarpImageMultiTransform(char *moving_image_filename, char *output_im
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
 // 'main()'
-int WarpTensorImageMultiTransform( std::vector<std::string> args, std::ostream* out_stream = NULL )
+int WarpTensorImageMultiTransform( std::vector<std::string> args, std::ostream* /*out_stream = NULL */ )
 {
   // put the arguments coming in as 'args' into standard (argc,argv) format;
   // 'args' doesn't have the command name as first, argument, so add it manually;
@@ -499,7 +499,7 @@ int WarpTensorImageMultiTransform( std::vector<std::string> args, std::ostream*
     // place the null character in the end
     argv[i][args[i].length()] = '\0';
     }
-  argv[argc] = 0;
+  argv[argc] = ITK_NULLPTR;
   // class to automatically cleanup argv upon destruction
   class Cleanup_argv
   {
@@ -523,11 +523,11 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
 
   if( argc <= 3 )
     {
-    antscout
+    std::cout
       <<
       "WarpImageMultiTransform ImageDimension moving_image output_image [-R reference_image | --tightest-bounding-box] (--reslice-by-header) [--use-NN (use Nearest Neighbor Interpolator)]"
       <<
@@ -556,7 +556,7 @@ private:
       "--reslice-by-header uses the orientation matrix and origin encoded in the image file header. It can be used together with -R. "
       << "This is typically not used together with any other transforms. "
       << "--reslice-by-header is equvalient to -i -mh, or -fh -i -mh if used together with -R. " << std::endl;
-    antscout << std::endl
+    std::cout << std::endl
              << "For ANTS users:" << std::endl
              << "To use with the deformation field and the affine transform files generated from ANTS:" << std::endl
              << "--ANTS-prefix prefix-name" << std::endl
@@ -582,8 +582,8 @@ private:
     }
 
   TRAN_OPT_QUEUE opt_queue;
-  char *         moving_image_filename = NULL;
-  char *         output_image_filename = NULL;
+  char *         moving_image_filename = ITK_NULLPTR;
+  char *         output_image_filename = ITK_NULLPTR;
 
   MISC_OPT misc_opt;
 
@@ -595,16 +595,16 @@ private:
 
   if( is_parsing_ok )
     {
-    antscout << "moving_image_filename: " << moving_image_filename << std::endl;
-    antscout << "output_image_filename: " << output_image_filename << std::endl;
-    antscout << "reference_image_filename: ";
+    std::cout << "moving_image_filename: " << moving_image_filename << std::endl;
+    std::cout << "output_image_filename: " << output_image_filename << std::endl;
+    std::cout << "reference_image_filename: ";
     if( misc_opt.reference_image_filename )
       {
-      antscout << misc_opt.reference_image_filename << std::endl;
+      std::cout << misc_opt.reference_image_filename << std::endl;
       }
     else
       {
-      antscout << "NULL" << std::endl;
+      std::cout << "NULL" << std::endl;
       }
     DisplayOptQueue(opt_queue);
 
@@ -624,7 +624,7 @@ private:
     }
   else
     {
-    antscout << "Input error!" << std::endl;
+    std::cout << "Input error!" << std::endl;
     }
   return EXIT_FAILURE;
 }
