@@ -154,9 +154,11 @@ public:
         }
       else
         {
-        std::cout << " "; // if the output of current iteration is written to disk, and star
+        this->Logger() << " "; // if the output of current iteration is written to disk, and star
         }                 // will appear before line, else a free space will be printed to keep visual alignment.
 
+      std::streamsize ss = std::cout.precision();
+
       this->Logger() << "1DIAGNOSTIC, "
                      << std::setw(5) << lCurrentIteration << ", "
                      << std::scientific << std::setprecision(12) << filter->GetCurrentMetricValue() << ", "
@@ -173,6 +175,9 @@ public:
         this->Logger() << std::endl;
         }
 
+      this->Logger() << std::setprecision( ss );
+      this->Logger().unsetf( std::ios::fixed | std::ios::scientific );
+
       this->m_lastTotalTime = now;
       m_clock.Start();
       }
@@ -389,6 +394,7 @@ public:
     inverseComposer->SetDisplacementField( const_cast<DisplacementFieldTransformType *>( filter->
                                                                                          GetFixedToMiddleTransform() )
                                            ->GetInverseDisplacementField() );
+
     inverseComposer->SetWarpingField(
       const_cast<DisplacementFieldTransformType *>( filter->GetMovingToMiddleTransform() )->GetDisplacementField() );
     inverseComposer->Update();
@@ -414,7 +420,10 @@ public:
     typedef typename TFilter::InitialTransformType InitialTransformType;
 
     typename CompositeTransformType::Pointer outputCompositTransform = CompositeTransformType::New();
-    outputCompositTransform->AddTransform( const_cast<InitialTransformType *>( filter->GetMovingInitialTransform() ) );
+    if( filter->GetMovingInitialTransform() )
+      {
+      outputCompositTransform->AddTransform( const_cast<InitialTransformType *>( filter->GetMovingInitialTransform() ) );
+      }
     outputCompositTransform->AddTransform( outputTransformReadyToUse );
     outputCompositTransform->FlattenTransformQueue();
     outputCompositTransform->SetOnlyMostRecentTransformToOptimizeOn();
