@@ -5,7 +5,7 @@ namespace ants {
 //Instantiate the 2DDouble version
 int antsRegistration2DDouble(ParserType::Pointer & parser)
 {
-    return  DoRegistration<2>( parser );
+    return  DoRegistration<double, 2>( parser );
 }
 
 } //end namespace ants
