@@ -40,6 +40,7 @@
 #include "itkIdentityTransform.h"
 #include "itkEuler2DTransform.h"
 #include "itkEuler3DTransform.h"
+#include "itkSimilarity2DTransform.h"
 #include "itkTransform.h"
 #include "itkExtractImageFilter.h"
 #include "itkBSplineTransformParametersAdaptor.h"
@@ -68,6 +69,7 @@
 #include "itkNearestNeighborInterpolateImageFunction.h"
 #include "itkWindowedSincInterpolateImageFunction.h"
 #include "itkLabelImageGaussianInterpolateImageFunction.h"
+#include "itkLabelImageGenericInterpolateImageFunction.h"
 #include <sstream>
 
 namespace ants
@@ -301,7 +303,45 @@ private:
   std::vector<unsigned int> m_NumberOfIterations;
 };
 
-template <unsigned int ImageDimension>
+
+void ants_slice_poly_regularize(
+  vnl_matrix<double> A,
+  unsigned int timedims,
+  vnl_vector<double>& solnx,
+  double& interceptx,
+  vnl_matrix<double> param_values,
+  unsigned int whichCol )
+{
+  typedef double RealType;
+  typedef vnl_vector<RealType>                      vVector;
+  for ( unsigned int z = 0; z < timedims; z++ )
+    {
+    RealType zz = static_cast<RealType>( z + 1 );
+    A(z,0) = zz;
+    for ( unsigned int lcol = 1; lcol < A.cols(); lcol++ )
+      {
+      A( z, lcol ) = std::pow( zz, static_cast<RealType>(lcol+1) );
+      }
+    }
+  for ( unsigned int lcol = 0; lcol < A.cols(); lcol++ )
+    {
+    vVector acol = A.get_column( lcol );
+    RealType acolsd = ( acol - acol.mean() ).rms();
+    A.set_column( lcol, ( acol - acol.mean() ) / acolsd );
+    }
+  vnl_svd<double>    svd( A );
+  vVector ob = param_values.get_column( whichCol );
+  vVector polyx = svd.solve( ob );
+  interceptx = param_values.get_column( whichCol ).mean();
+  for( unsigned int Acol = 0; Acol < A.cols(); Acol++ )
+    {
+    interceptx -= A.get_column( Acol ).mean() * polyx( Acol );
+    }
+  solnx = A * polyx + interceptx;
+  }
+
+
+template <unsigned int ImageDimension, class TXType>
 int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
 {
   // We infer the number of stages by the number of transformations
@@ -407,11 +447,10 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
 
   itk::TimeProbe totalTimer;
   totalTimer.Start();
-  typedef itk::TranslationTransform<RealType, ImageDimension-1> TranslationTransformType;
-  typedef itk::ImageRegistrationMethodv4<FixedImageType, MovingImageType, TranslationTransformType>
+  typedef itk::ImageRegistrationMethodv4<FixedImageType, MovingImageType, TXType>
                                                            TranslationRegistrationType;
   // We iterate backwards because the command line options are stored as a stack (first in last out)
-  typedef typename TranslationTransformType::Pointer       SingleTransformItemType;
+  typedef typename TXType::Pointer       SingleTransformItemType;
   std::vector<SingleTransformItemType>                     transformList;
   std::vector<SingleTransformItemType>                     transformUList;
   std::vector<typename FixedImageType::Pointer>            fixedSliceList;
@@ -435,7 +474,8 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
     typename FixedIOImageType::Pointer fixedImage;
     ReadImage<FixedIOImageType>( fixedImage, fixedImageFileName.c_str() );
     unsigned int timedims = fixedImage->GetLargestPossibleRegion().GetSize()[ImageDimension-1];
-    param_values.set_size(timedims, 2 );
+    unsigned int nparams = TXType::New()->GetNumberOfParameters();
+    param_values.set_size(timedims, nparams );
     param_values.fill(0);
 
     typename MovingIOImageType::Pointer movingImage;
@@ -457,7 +497,6 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
     unsigned int numberOfLevels = iterations.size();
 
     // Get shrink factors
-
     std::vector<unsigned int> factors =
       parser->ConvertVector<unsigned int>( shrinkFactorsOption->GetFunction( currentStage )->GetName()  );
     typename TranslationRegistrationType::ShrinkFactorsArrayType shrinkFactorsPerLevel;
@@ -502,13 +541,21 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
     verbose = true;
     }
 
-  unsigned int polydegree = 3;
+
+  std::vector<unsigned int> polydegree;
   itk::ants::CommandLineParser::OptionType::Pointer polyOption = parser->GetOption( "polydegree" );
   if( polyOption && polyOption->GetNumberOfFunctions() )
     {
-    polydegree = parser->Convert<unsigned int>( polyOption->GetFunction( 0 )->GetName() );
+    polydegree = parser->ConvertVector<unsigned int>( polyOption->GetFunction( 0 )->GetName() );
+    }
+  if ( ( polydegree.size() != nparams )  )
+    {
+    polydegree.resize( nparams, polydegree[ 0 ] );
+    }
+  for ( unsigned int pind = 0; pind < polydegree.size(); pind++ )
+    {
+    if ( polydegree[pind] > (timedims-2) ) polydegree[pind] = timedims-2;
     }
-  if ( polydegree > (timedims-2) ) polydegree = timedims-2;
 
     // the fixed image slice is a reference image in 2D while the moving is a 2D slice image
     // loop over every time point and register image_i_moving to image_i_fixed
@@ -553,14 +600,13 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
         mask_time_slice = extractFilterX->GetOutput();
         }
 
-
       // set up initial transform parameters
-      typename TranslationTransformType::Pointer translationTransform = TranslationTransformType::New();
+      typename TXType::Pointer translationTransform = TXType::New();
       translationTransform->SetIdentity();
       transformList.push_back( translationTransform );
 
       // set up update transform parameters
-      typename TranslationTransformType::Pointer translationTransformU = TranslationTransformType::New();
+      typename TXType::Pointer translationTransformU = TXType::New();
       translationTransformU->SetIdentity();
       transformUList.push_back( translationTransformU );
       }
@@ -592,7 +638,6 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
         skipThisTimePoint = true;
         }
 
-
       std::string whichMetric = metricOption->GetFunction( currentStage )->GetName();
       ConvertToLowerCase( whichMetric );
 
@@ -699,7 +744,9 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
       std::string whichTransform = transformOption->GetFunction( currentStage )->GetName();
       ConvertToLowerCase( whichTransform );
       typename TranslationRegistrationType::Pointer translationRegistration = TranslationRegistrationType::New();
-      if( std::strcmp( whichTransform.c_str(), "translation" ) == 0 )
+      if ( ( std::strcmp( whichTransform.c_str(), "translation" ) == 0 ) |
+           ( std::strcmp( whichTransform.c_str(), "rigid" ) == 0 ) |
+           ( std::strcmp( whichTransform.c_str(), "similarity" ) == 0 ) )
         {
         transformList[timedim]->GetNumberOfParameters();
         metric->SetFixedImage( preprocessFixedImage );
@@ -737,7 +784,7 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
           std::cerr << "Exception caught: " << e << std::endl;
           return EXIT_FAILURE;
           }
-	}
+	      }
       else
         {
         std::cerr << "ERROR:  Unrecognized transform option - " << whichTransform << std::endl;
@@ -749,90 +796,93 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
 
   for ( unsigned int i = 0; i < transformList.size(); i++)
     {
-    typename TranslationTransformType::ParametersType pu = transformUList[i]->GetParameters();
-    param_values( i, 0 )=pu[ 0 ];
-    param_values( i, 1 )=pu[ 1 ];
+    typename TXType::ParametersType pu = transformUList[i]->GetParameters();
+    for ( unsigned int kk = 0; kk < pu.Size(); kk++ )
+      param_values( i, kk ) = pu[ kk ];
     }
 
-  // project updated solution back to polynomial space
-  if ( polydegree > 0 )
+// project updated solution back to polynomial space
+vVector solnx;
+RealType interceptx = 0;
+if ( polydegree[ 0 ] > 0 )
   {
   // set up polynomial system of equations
-  vMatrix A( timedims, polydegree, 0.0 );
-  for ( unsigned int z = 0; z < timedims; z++ )
-    {
-    RealType zz = static_cast<RealType>( z + 1 );
-    A(z,0) = zz;
-    for ( unsigned int lcol = 1; lcol < A.cols(); lcol++ )
-      {
-      A( z, lcol ) = vcl_pow( zz, static_cast<RealType>(lcol+1) );
-      }
-    }
-  for ( unsigned int lcol = 0; lcol < A.cols(); lcol++ )
-    {
-    vVector acol = A.get_column( lcol );
-    RealType acolsd = ( acol - acol.mean() ).rms();
-    A.set_column( lcol, ( acol - acol.mean() ) / acolsd );
-    }
-  vnl_svd<double>    svd( A );
+  vMatrix A( timedims, polydegree[ 0 ], 0.0 );
+  ants_slice_poly_regularize( A, timedims, solnx, interceptx, param_values, 0 );
+  }
 
-  // first x-dimension
-  vVector ob = param_values.get_column( 0 );
-  RealType bsd = ( ob - ob.mean() ).rms();
-  vVector b = ( ob - ob.mean() ) / bsd;
-  vVector polyx = svd.solve( ob );
-  RealType interceptx = param_values.get_column( 0 ).mean();
-  for( unsigned int Acol = 0; Acol < A.cols(); Acol++ )
-    {
-    interceptx -= A.get_column( Acol ).mean() * polyx( Acol );
-    }
-  vVector solnx = A * polyx + interceptx;
+// now y-dimension
+vVector solny;
+RealType intercepty = 0;
+if ( polydegree[ 1 ] > 0 )
+  {
+  vMatrix A( timedims, polydegree[ 1 ], 0.0 );
+  ants_slice_poly_regularize( A, timedims, solny, intercepty, param_values, 1 );
+  }
 
-  // now y-dimension
-  ob = param_values.get_column( 1 );
-  bsd = ( ob - ob.mean() ).rms();
-  b = ( ob - ob.mean() ) / bsd;
-  vVector polyy = svd.solve( ob );
-  RealType intercepty = param_values.get_column( 1 ).mean();
-  for( unsigned int Acol = 0; Acol < A.cols(); Acol++ )
-    {
-    intercepty -= A.get_column( Acol ).mean() * polyy( Acol );
-    }
-  vVector solny = A * polyy + intercepty;
+// now rotation
+vVector solnr;
+RealType interceptr = 0;
+if ( nparams >= 3 )
+if ( polydegree[ 2 ] > 0 )
+  {
+  vMatrix A( timedims, polydegree[ 2 ], 0.0 );
+  ants_slice_poly_regularize( A, timedims, solnr, interceptr, param_values, 2 );
+  }
 
-  // now look at delta and do projection
-  if ( solnx.size() != transformList.size() )
-    {
-    std::cerr << "solnx.size() != transformList.size()" << std::endl;
+// now scaling-dimension
+vVector solns;
+RealType intercepts = 0;
+if ( nparams >= 4 )
+if ( polydegree[ 3 ] > 0 )
+  {
+  vMatrix A( timedims, polydegree[ 3 ], 0.0 );
+  ants_slice_poly_regularize( A, timedims, solns, intercepts, param_values, 3 );
+  }
+
+// now look at delta and do projection
+if ( ( solnx.size() != transformList.size() ) && ( polydegree[ 0 ] > 0 ) )
+  std::cerr << "solnx.size() != transformList.size()" << std::endl;
+if ( ( solny.size() != transformList.size() ) && ( polydegree[ 1 ] > 0 ) )
+  std::cerr << "solny.size() != transformList.size()" << std::endl;
+
+RealType err = 0;
+for ( unsigned int i = 0; i < transformList.size(); i++)
+  {
+  /** FIXME - this should be vectorized: DRY */
+  typename TXType::ParametersType pOld = transformList[i]->GetParameters();
+  typename TXType::ParametersType p = transformList[i]->GetParameters();
+  if ( polydegree[ 0 ] > 0 ) p[ 0 ] = solnx[ i ];
+  if ( polydegree[ 1 ] > 0 ) p[ 1 ] = solny[ i ];
+  param_values( i, 0 ) = p[ 0 ];
+  param_values( i, 1 ) = p[ 1 ];
+  if ( nparams >= 3 ) {
+    if ( polydegree[ 2 ] > 0 ) p[ 2 ] = solnr[i];
+    param_values( i, 2 ) = p[ 2 ];
     }
-  RealType err = 0;
-  RealType eulerparam = 1;
-  for ( unsigned int i = 0; i < transformList.size(); i++)
-    {
-    typename TranslationTransformType::ParametersType p = transformList[i]->GetParameters();
-    err += vcl_sqrt( vcl_pow( p[0] - solnx[i] , 2.0 ) + vcl_pow( p[1] - solny[i] , 2.0 ) );
-    p[ 0 ] = solnx[i] * eulerparam + p[0] * (1.0 - eulerparam);
-    p[ 1 ] = solny[i] * eulerparam + p[1] * (1.0 - eulerparam);
-    param_values(i,0) = p[0];
-    param_values(i,1) = p[1];
-    transformList[i]->SetParameters( p );
+  if ( nparams >= 4 ) {
+    if ( polydegree[ 3 ] > 0 ) p[ 3 ] = solns[i];
+    param_values(i,3) = p[3];
     }
+  transformList[i]->SetParameters( p );
+  transformUList[i]->SetParameters( p );
+  err += ( p - pOld ).rms();
+  }
+  err = err / static_cast< double >( transformList.size() );
   if ( verbose )
     {
-    std::cout << "Loop" << loop << " polyerr: " << err / timedims <<  " image-metric " << metricval << std::endl;
-    std::cout << " polyx " << polyx << " iceptx " << interceptx  << std::endl;
-    std::cout << " polyy " << polyy << " icepty " << intercepty  << std::endl;
+    std::cout << "Loop" << loop << " polyerr: " << err <<  " image-metric " << metricval << std::endl;
     }
-  } else {  // polydegree == 0
-    transformList = transformUList;
-    for ( unsigned int i = 0; i < transformList.size(); i++)
-      {
-      typename TranslationTransformType::ParametersType p = transformList[i]->GetParameters();
-      param_values(i,0) = p[0];
-      param_values(i,1) = p[1];
-      }
+//  transformList = transformUList;
+  for ( unsigned int i = 0; i < transformList.size(); i++)
+    {
+    typename TXType::ParametersType p = transformList[i]->GetParameters();
+    if ( polydegree[0] == 0 ) param_values(i,0) = p[0];
+    if ( polydegree[1] == 0 ) param_values(i,1) = p[1];
+    if ( nparams >= 3 ) if ( polydegree[2] == 0 ) param_values(i,2) = p[2];
+    if ( nparams >= 4 ) if ( polydegree[3] == 0 ) param_values(i,3) = p[3];
     }
-  }// done with optimization, now move on to writing data ...
+  }// done with optimization, now move on to writing data ... closes for ( unsigned int loop = 0; loop < maxloop; loop++ )
 
   // write polynomial predicted data
     {
@@ -842,6 +892,14 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
     ColumnHeaders.push_back( colname );
     colname = std::string("Ty");
     ColumnHeaders.push_back( colname );
+    if ( nparams >= 3 ) {
+      colname = std::string("Tr");
+      ColumnHeaders.push_back( colname );
+      }
+    if ( nparams >= 4 ) {
+      colname = std::string("Ts");
+      ColumnHeaders.push_back( colname );
+      }
     typedef itk::CSVNumericObjectFileWriter<double, 1, 1> WriterType;
     WriterType::Pointer writer = WriterType::New();
     std::string         fnmp;
@@ -921,40 +979,49 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
         }
       }
 
-// now apply to the inverse mapﬁ
-      for( unsigned int timedim = 0; timedim < timedims; timedim++ )
+// now apply to the inverse map
+      unsigned int timedimX = 0;
+      for( timedimX = 0; timedimX < timedims; timedimX++ )
         {
         typedef typename itk::TransformToDisplacementFieldFilter<DisplacementFieldType, RealType>
           _ConverterType;
         typename _ConverterType::Pointer converter = _ConverterType::New();
-        converter->SetOutputOrigin( movingSliceList[timedim]->GetOrigin() );
-        converter->SetOutputStartIndex( movingSliceList[timedim]->GetBufferedRegion().GetIndex() );
-        converter->SetSize( movingSliceList[timedim]->GetBufferedRegion().GetSize() );
-        converter->SetOutputSpacing( movingSliceList[timedim]->GetSpacing() );
-        converter->SetOutputDirection( movingSliceList[timedim]->GetDirection() );
-        typename TranslationTransformType::Pointer invtx = TranslationTransformType::New();
+        converter->SetOutputOrigin( movingSliceList[ timedimX ]->GetOrigin() );
+        converter->SetOutputStartIndex(
+          movingSliceList[ timedimX ]->GetBufferedRegion().GetIndex() );
+        converter->SetSize( movingSliceList[
+          timedimX ]->GetBufferedRegion().GetSize() );
+        converter->SetOutputSpacing(
+          movingSliceList[ timedimX ]->GetSpacing() );
+        converter->SetOutputDirection(
+          movingSliceList[ timedimX ]->GetDirection() );
+        typename TXType::Pointer invtx =
+         TXType::New();
         invtx->SetIdentity();
-        transformList[timedim]->GetInverse( invtx );
+        transformList[ timedimX ]->GetInverse( invtx );
         converter->SetTransform( invtx );
         converter->Update();
 
         // resample the moving image and then put it in its place
         typedef itk::ResampleImageFilter<FixedImageType, FixedImageType> ResampleFilterType;
-        typename ResampleFilterType::Pointer resampler = ResampleFilterType::New();
+        typename ResampleFilterType::Pointer resampler =
+          ResampleFilterType::New();
         resampler->SetTransform( invtx );
-        interpolator->SetInputImage( fixedSliceList[timedim] );
+        interpolator->SetInputImage( fixedSliceList[ timedimX ] );
         resampler->SetInterpolator( interpolator );
-        resampler->SetInput( fixedSliceList[timedim] );
-        resampler->SetOutputParametersFromImage( movingSliceList[timedim] );
+        resampler->SetInput( fixedSliceList[ timedimX ] );
+        resampler->SetOutputParametersFromImage( movingSliceList[ timedimX ] );
         resampler->SetDefaultPixelValue( 0 );
         resampler->Update();
 
         /** Here, we put the resampled 2D image into the 3D volume */
         typedef itk::ImageRegionIteratorWithIndex<FixedImageType> Iterator;
-        Iterator vfIter2(  resampler->GetOutput(), resampler->GetOutput()->GetLargestPossibleRegion() );
+        Iterator vfIter2(  resampler->GetOutput(),
+          resampler->GetOutput()->GetLargestPossibleRegion() );
         for(  vfIter2.GoToBegin(); !vfIter2.IsAtEnd(); ++vfIter2 )
           {
-          VectorType vec = converter->GetOutput()->GetPixel( vfIter2.GetIndex() );
+          VectorType vec = converter->GetOutput()->GetPixel(
+            vfIter2.GetIndex() );
           VectorIOType vecout;
           vecout.Fill( 0 );
           typename MovingIOImageType::IndexType ind;
@@ -963,7 +1030,7 @@ int ants_slice_regularized_registration( itk::ants::CommandLineParser *parser )
             ind[xx] = vfIter2.GetIndex()[xx];
             vecout[xx] = vec[xx];
             }
-          unsigned int tdim = timedim;
+          unsigned int tdim = timedimX;
           if( tdim > ( timedims - 1 ) )
             {
             tdim = timedims - 1;
@@ -1070,6 +1137,7 @@ void antsSliceRegularizedRegistrationInitializeCommandLineOptions( itk::ants::Co
     option->SetUsageOption( 6, "WelchWindowedSinc" );
     option->SetUsageOption( 7, "HammingWindowedSinc" );
     option->SetUsageOption( 8, "LanczosWindowedSinc" );
+    option->SetUsageOption( 9, "GenericLabel[<interpolator=Linear>]" );
     option->SetDescription( description );
     parser->AddOption( option );
     }
@@ -1084,6 +1152,8 @@ void antsSliceRegularizedRegistrationInitializeCommandLineOptions( itk::ants::Co
     option->SetLongName( "transform" );
     option->SetShortName( 't' );
     option->SetUsageOption( 0, "Translation[gradientStep]" );
+    option->SetUsageOption( 1, "Rigid[gradientStep]" );
+    option->SetUsageOption( 2, "Similarity[gradientStep]" );
     option->SetDescription( description );
     parser->AddOption( option );
     }
@@ -1156,7 +1226,12 @@ void antsSliceRegularizedRegistrationInitializeCommandLineOptions( itk::ants::Co
     }
 
     {
-    std::string description = std::string( "degree of polynomial - up to zDimension-2. Controls the polynomial degree. 0 means no regularization.");
+    std::string description =
+    std::string( "degree of polynomial - up to zDimension-2. ") +
+    std::string( "Controls the polynomial degree. 0 means no regularization. This may be a vector ") +
+    std::string( "denoted by 2x2x1 for a 3-parameter transform ( e.g. rigid ).  This would ") +
+    std::string( "regularize the translation by 2nd degree polynomial and the rotation by a ") +
+    std::string( "linear function.");
     OptionType::Pointer option = OptionType::New();
     option->SetLongName( "polydegree" );
     option->SetShortName( 'p' );
@@ -1258,18 +1333,67 @@ private:
 
   // Get dimensionality
   unsigned int dimension = 3;
-  switch( dimension )
+  typedef double                                    RealType;
+  typedef itk::TranslationTransform<RealType, 2> TranslationTransformType;
+  typedef itk::Euler2DTransform<RealType> EulerTransformType;
+  typedef itk::Similarity2DTransform<RealType> SimilarityTransformType;
+
+  itk::ants::CommandLineParser::OptionType::Pointer transformOption =
+    parser->GetOption( "transform" );
+  if( ! (transformOption && transformOption->GetNumberOfFunctions() ) )
     {
-    case 3:
-      {
-      ants_slice_regularized_registration<3>( parser );
-      }
-      break;
-    default:
-      std::cerr << "Unsupported dimension" << std::endl;
-      return EXIT_FAILURE;
+    std::cerr << "No transformations are specified." << std::endl;
+    return EXIT_FAILURE;
     }
-  return 0;
+  std::string whichTransform = transformOption->GetFunction( 0 )->GetName();
+  ConvertToLowerCase( whichTransform );
+  if( std::strcmp( whichTransform.c_str(), "translation" ) == 0 )
+    {
+    switch( dimension )
+      {
+      case 3:
+        {
+        return ants_slice_regularized_registration<3,TranslationTransformType>( parser );
+        }
+        break;
+      default:
+        std::cerr << "Unsupported dimension" << std::endl;
+        return EXIT_FAILURE;
+      }
+    return EXIT_SUCCESS;
+    }
+  else if( std::strcmp( whichTransform.c_str(), "rigid" ) == 0 )
+    {
+    switch( dimension )
+      {
+      case 3:
+        {
+        return ants_slice_regularized_registration<3,EulerTransformType>( parser );
+        }
+        break;
+      default:
+        std::cerr << "Unsupported dimension" << std::endl;
+        return EXIT_FAILURE;
+      }
+    return EXIT_SUCCESS;
+    }
+  else if( std::strcmp( whichTransform.c_str(), "similarity" ) == 0 )
+    {
+    switch( dimension )
+      {
+      case 3:
+        {
+        return ants_slice_regularized_registration<3,SimilarityTransformType>( parser );
+        }
+        break;
+      default:
+        std::cerr << "Unsupported dimension" << std::endl;
+        return EXIT_FAILURE;
+      }
+    return EXIT_SUCCESS;
+    }
+
+  return EXIT_SUCCESS;
 }
 
 } // namespace ants
