@@ -1,12 +1,30 @@
 #ifndef ants_h
 #define ants_h
 
+#include "../../Utilities/itkSurfaceCurvatureBase.h"
+
+#include "../../Utilities/itkSurfaceImageCurvature.h"
+
+#include "../../Utilities/itkAlternatingValueSimpleSubtractionImageFilter.h"
+
+#include "../../Utilities/itkAverageOverDimensionImageFilter.h"
+
+#include "../../Utilities/itkAlternatingValueDifferenceImageFilter.h"
+
+#include "antsAffineInitializer.h"
+
+#include "antsAI.h"
+
 #include "antsApplyTransforms.h"
 
 #include "antsAlignOrigin.h"
 
 #include "antsApplyTransformsToPoints.h"
 
+#include "antsJointFusion.h"
+
+#include "antsJointTensorFusion.h"
+
 #include "antsTransformInfo.h"
 
 #include "ANTSConformalMapping.h"
@@ -35,12 +53,16 @@
 
 #include "antsUtilitiesTesting.h"
 
+#include "antsVol.h"
+
 #include "ANTSUseDeformationFieldToGetAffineTransform.h"
 
 #include "ANTSUseLandmarkImagesToGetAffineTransform.h"
 
 #include "ANTSUseLandmarkImagesToGetBSplineDisplacementField.h"
 
+#include "antsLandmarkBasedTransformInitializer.h"
+
 #include "Atropos.h"
 
 #include "AverageAffineTransform.h"
@@ -63,6 +85,8 @@
 
 #include "ConformalMapping.h"
 
+#include "ConvertImage.h"
+
 #include "ConvertImagePixelType.h"
 
 #include "ConvertInputImagePixelTypeToFloat.h"
@@ -89,24 +113,26 @@
 
 #include "DeNrrd.h"
 
+#include "DenoiseImage.h"
+
 #include "ExtractRegionFromImageByMask.h"
 
 #include "ExtractRegionFromImage.h"
 
 #include "ExtractSliceFromImage.h"
 
-#include "FitBSplineCurveToPoints.h"
+#include "FitBSplineToPoints.h"
 
 #include "GetMeshAndTopology.h"
 
+#include "iMath.h"
+
 #include "ImageCompare.h"
 
 #include "ImageMath.h"
 
 #include "ImageIntensityStatistics.h"
 
-#include "antsAffineInitializer.h"
-
 // #include "antsSimilarityInitializer.h"
 
 #include "ImageSetStatistics.h"
@@ -139,6 +165,8 @@
 
 #include "N4BiasFieldCorrection.h"
 
+#include "NonLocalSuperResolution.h"
+
 #include "PasteImageIntoImage.h"
 
 #include "PermuteFlipImageOrientationAxes.h"
@@ -167,10 +195,14 @@
 
 #include "SmoothImage.h"
 
+#include "SmoothDisplacementField.h"
+
 #include "StackSlices.h"
 
 #include "StudentsTestOnImages.h"
 
+#include "SuperResolution.h"
+
 #include "SurfaceBasedSmoothing.h"
 
 #include "SurfaceCurvature.h"
