@@ -1,14 +1,10 @@
 /*=========================================================================
 
  Program:   Advanced Normalization Tools
- Module:    $RCSfile: itkANTSImageRegistrationOptimizer.h,v $
- Language:  C++
- Date:      $Date: 2009/04/22 01:00:17 $
- Version:   $Revision: 1.44 $
 
  Copyright (c) ConsortiumOfANTS. All rights reserved.
  See accompanying COPYING.txt or
- http://sourceforge.net/projects/advants/files/ANTS/ANTSCopyright.txt for details.
+ https://github.com/stnava/ANTs/blob/master/ANTSCopyright.txt for details.
 
  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -254,12 +250,12 @@ public:
           for( unsigned int d = 0; d < ImageDimension; d++ )
             {
             meshSize[d] *= static_cast<unsigned int>(
-                vcl_pow( 2.0, static_cast<int>( this->m_CurrentLevel ) ) );
+                std::pow( 2.0, static_cast<int>( this->m_CurrentLevel ) ) );
             }
           }
         else
           {
-          TReal spanLength = vcl_sqrt( this->m_GradSmoothingparam
+          TReal spanLength = std::sqrt( this->m_GradSmoothingparam
                                        / bsplineKernelVariance );
           for( unsigned int d = 0; d < ImageDimension; d++ )
             {
@@ -279,12 +275,12 @@ public:
           for( unsigned int d = 0; d < ImageDimension; d++ )
             {
             meshSize[d] *= static_cast<unsigned int>(
-                vcl_pow( 2.0, static_cast<int>( this->m_CurrentLevel ) ) );
+                std::pow( 2.0, static_cast<int>( this->m_CurrentLevel ) ) );
             }
           }
         else
           {
-          TReal spanLength = vcl_sqrt( this->m_TotalSmoothingparam
+          TReal spanLength = std::sqrt( this->m_TotalSmoothingparam
                                        / bsplineKernelVariance );
           for( unsigned int d = 0; d < ImageDimension; d++ )
             {
@@ -358,7 +354,7 @@ public:
 
     expandFactors[ImageDimension] = 1;
 //     m_Debug = false;
-    for( int idim = 0; idim < ImageDimension; idim++ )
+    for( unsigned int idim = 0; idim < ImageDimension; idim++ )
       {
       expandFactors[idim] = (float) this->m_CurrentDomainSize[idim]
         / (TReal) this->m_TimeVaryingVelocity->GetLargestPossibleRegion().GetSize()[idim];
@@ -387,7 +383,7 @@ public:
 //      this->m_Debug=true;
     float expandFactors[ImageDimension];
 
-    for( int idim = 0; idim < ImageDimension; idim++ )
+    for( unsigned int idim = 0; idim < ImageDimension; idim++ )
       {
       expandFactors[idim] = (TReal) this->m_CurrentDomainSize[idim]
         / (TReal)field->GetLargestPossibleRegion().GetSize()[idim];
@@ -1178,12 +1174,7 @@ public:
       if( subsamplingfactors.size() > 0 )
         {
         std::vector<float> factors = this->m_Parser->template ConvertVector<float>( subsamplingfactors );
-        if( factors.size() != this->m_NumberOfLevels )
-          {
-          itkWarningMacro( "The number of levels does not match the size of factors."
-                           << "  Using default settings." );
-          }
-        else
+        if( factors.size() == this->m_NumberOfLevels )
           {
           this->m_SubsamplingFactors.SetSize( this->m_NumberOfLevels );
           for( unsigned int d = 0; d < this->m_NumberOfLevels; d++ )
@@ -1191,6 +1182,11 @@ public:
             this->m_SubsamplingFactors[d] = factors[d];
             }
           }
+//         else
+//           {
+//           itkWarningMacro( "The number of levels does not match the size of factors."
+//                            << "  Using default settings." );
+//           }
         }
       }
 
@@ -1201,12 +1197,7 @@ public:
       {
       std::string        gaussiansmoothingsigmas = gaussianSmoothingSigmasOption->GetFunction()->GetName();
       std::vector<float> sigmas = this->m_Parser->template ConvertVector<float>( gaussiansmoothingsigmas );
-      if( sigmas.size() != this->m_NumberOfLevels )
-        {
-        itkWarningMacro( "The number of levels does not match the size of sigmas."
-                         << "  Using default settings." );
-        }
-      else
+      if( sigmas.size() == this->m_NumberOfLevels )
         {
         this->m_GaussianSmoothingSigmas.SetSize( this->m_NumberOfLevels );
         for( unsigned int d = 0; d < this->m_NumberOfLevels; d++ )
@@ -1214,6 +1205,11 @@ public:
           this->m_GaussianSmoothingSigmas[d] = sigmas[d];
           }
         }
+//       else
+//         {
+//         itkWarningMacro( "The number of levels does not match the size of sigmas."
+//                          << "  Using default settings." );
+//         }
       }
 
     unsigned int maxits = 0;
@@ -1288,7 +1284,7 @@ public:
 
       if( this->m_SubsamplingFactors.Size() == 0 )
         {
-        this->m_ScaleFactor = vcl_pow( 2.0, (int)static_cast<RealType>( this->m_NumberOfLevels - currentLevel - 1 ) );
+        this->m_ScaleFactor = std::pow( 2.0, (int)static_cast<RealType>( this->m_NumberOfLevels - currentLevel - 1 ) );
         }
       else
         {
@@ -1834,7 +1830,7 @@ public:
     typename ImageType::SpacingType spacing = field->GetSpacing();
 
     unsigned long npix = 1;
-    for( int j = 0; j < ImageDimension; j++ ) // only use in-plane spacing
+    for( unsigned int j = 0; j < ImageDimension; j++ ) // only use in-plane spacing
       {
       npix *= field->GetLargestPossibleRegion().GetSize()[j];
       }
@@ -1898,7 +1894,7 @@ public:
         DispIndexType  index = vfIter.GetIndex();
         DispVectorType update = eulerianInitCond->GetPixel(index);
         TReal          mag = 0;
-        for( int j = 0; j < ImageDimension; j++ )
+        for( unsigned int j = 0; j < ImageDimension; j++ )
           {
           update[j] *= (-1.0);
           mag += (update[j] / spacing[j]) * (update[j] / spacing[j]);
@@ -2040,7 +2036,7 @@ protected:
       DispVectorType update = vfIter.Get();
       TReal          mag = 0.0;
       TReal          stepl = 0.0;
-      for( int i = 0; i < ImageDimension; i++ )
+      for( unsigned int i = 0; i < ImageDimension; i++ )
         {
         rindex = index;
         lindex = index;
@@ -2055,7 +2051,7 @@ protected:
         DispVectorType rupdate = field->GetPixel(rindex);
         DispVectorType lupdate = field->GetPixel(lindex);
         DispVectorType dif = rupdate - lupdate;
-        for( int tt = 0; tt < ImageDimension; tt++ )
+        for( unsigned int tt = 0; tt < ImageDimension; tt++ )
           {
           stepl += update[tt] * update[tt] / (myspacing[tt] * myspacing[tt]);
           mag += dif[tt] * dif[tt] / (myspacing[tt] * myspacing[tt]);
