@@ -108,6 +108,7 @@ Optional arguments:
      -f:  extraction registration mask          Mask (defined in the template space) used during registration
                                                 for brain extraction.
      -k:  keep temporary files                  Keep brain extraction/segmentation warps, etc (default = 0).
+     -g:  denoise anatomical images             Denoise anatomical images (default = 0).
      -i:  max iterations for registration       ANTS registration max iterations (default = 100x100x70x20)
      -w:  Atropos prior segmentation weight     Atropos spatial prior *probability* weight for the segmentation (default = 0.25)
      -n:  number of segmentation iterations     N4 -> Atropos -> N4 iterations during segmentation (default = 3)
@@ -139,6 +140,15 @@ Optional arguments:
      -q:  Use quick registration parameters     If = 1, use antsRegistrationSyNQuick.sh as the basis for registration
                                                 during brain extraction, brain segmentation, and (optional) normalization
                                                 to a template.  Otherwise use antsRegistrationSyN.sh (default = 0).
+     -x:                                        Number of iterations within Atropos (default 5).
+     -y:                                        Which stage of ACT to run (default = 0, run all).  Tries to split in 2 hour chunks.
+                                                Will produce OutputNameACTStageNComplete.txt for each completed stage.
+                                                1: brain extraction
+                                                2: template registration
+                                                3: tissue segmentation
+                                                4: template registration (improved, optional)
+                                                5: DiReCT cortical thickness
+                                                6: qc, quality control and summary measurements
      -z:  Test / debug mode                     If > 0, runs a faster version of the script. Only for testing. Implies -u 0.
                                                 Requires single thread computation for complete reproducibility.
 USAGE
@@ -230,6 +240,7 @@ echoParameters() {
     Other parameters:
       run quick               = ${RUN_QUICK}
       debug mode              = ${DEBUG_MODE}
+      denoise images          = ${DENOISE_ANATOMICAL_IMAGES}
       float precision         = ${USE_FLOAT_PRECISION}
       use random seeding      = ${USE_RANDOM_SEEDING}
       prior combinations      = ${PRIOR_COMBINATIONS[@]}
@@ -241,6 +252,8 @@ PARAMETERS
 # Will immediately exit on error unless you set debug flag here
 DEBUG_MODE=0
 
+ACT_STAGE=0 # run all stages
+
 function logCmd() {
   cmd="$*"
   echo "BEGIN >>>>>>>>>>>>>>>>>>>>"
@@ -292,6 +305,8 @@ DO_REGISTRATION_TO_TEMPLATE=0
 USE_RANDOM_SEEDING=1
 RUN_QUICK=0
 
+DENOISE_ANATOMICAL_IMAGES=0
+
 BRAIN_TEMPLATE=""
 EXTRACTION_PRIOR=""
 EXTRACTION_REGISTRATION_MASK=""
@@ -335,6 +350,7 @@ ATROPOS_SEGMENTATION_LIKELIHOOD="Gaussian"
 ATROPOS_SEGMENTATION_CONVERGENCE="[5,0.0]"
 ATROPOS_SEGMENTATION_POSTERIOR_FORMULATION="Socrates[1]"
 ATROPOS_SEGMENTATION_NUMBER_OF_ITERATIONS=3
+ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS=5 # to be backward compatible but i like 25
 ATROPOS_SEGMENTATION_LABEL_PROPAGATION=()
 
 DIRECT=${ANTSPATH}/KellyKapowski
@@ -353,7 +369,7 @@ if [[ $# -lt 3 ]] ; then
   Usage >&2
   exit 1
 else
-  while getopts "a:b:c:d:e:f:h:i:j:k:l:m:n:o:p:q:r:s:t:u:v:w:z:" OPT
+  while getopts "a:b:c:d:e:f:g:h:i:j:k:l:m:n:o:p:q:r:s:t:u:v:w:x:y:z:" OPT
     do
       case $OPT in
           a) #anatomical t1 image
@@ -378,6 +394,9 @@ else
        ;;
           f) #brain extraction registration mask
        EXTRACTION_REGISTRATION_MASK=$OPTARG
+       ;;
+          g) # denoise anatomical images
+       DENOISE_ANATOMICAL_IMAGES=$OPTARG
        ;;
           h) #help
        Usage >&2
@@ -400,6 +419,9 @@ else
        ;;
           n) #atropos segmentation iterations
        ATROPOS_SEGMENTATION_NUMBER_OF_ITERATIONS=$OPTARG
+       ;;
+          x) #atropos segmentation internal iterations
+       ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS=$OPTARG
        ;;
           o) #output prefix
        OUTPUT_PREFIX=$OPTARG
@@ -428,6 +450,9 @@ else
        ;;
           w) #atropos prior weight
        ATROPOS_SEGMENTATION_PRIOR_WEIGHT=$OPTARG
+       ;;
+          y) #which stage
+       ACT_STAGE=$OPTARG
        ;;
           z) #debug mode
        DEBUG_MODE=$OPTARG
@@ -462,6 +487,7 @@ if [[ $DEBUG_MODE -gt 0 ]];
 
     # I think this is the number of times we run the whole N4 / Atropos thing, at the cost of about 10 minutes a time
     ATROPOS_SEGMENTATION_NUMBER_OF_ITERATIONS=1
+    ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS=5 # internal to atropos
 
     DIRECT_CONVERGENCE="[5,0.0,10]"
 
@@ -475,7 +501,6 @@ if [[ $DEBUG_MODE -gt 0 ]];
 # Preliminaries:
 #  1. Check existence of inputs
 #  2. Figure out output directory and mkdir if necessary
-#  3. See if $REGISTRATION_TEMPLATE is the same as $BRAIN_TEMPLATE
 #
 ################################################################################
 
@@ -488,19 +513,6 @@ for (( i = 0; i < ${#ANATOMICAL_IMAGES[@]}; i++ ))
     fi
   done
 
-if [[ ! -f ${BRAIN_TEMPLATE} ]];
-  then
-    echo "The extraction template doesn't exist:"
-    echo "   $BRAIN_TEMPLATE"
-    exit 1
-  fi
-if [[ ! -f ${EXTRACTION_PRIOR} ]];
-  then
-    echo "The brain extraction prior doesn't exist:"
-    echo "   $EXTRACTION_PRIOR"
-    exit 1
-  fi
-
 FORMAT=${SEGMENTATION_PRIOR}
 PREFORMAT=${FORMAT%%\%*}
 POSTFORMAT=${FORMAT##*d}
@@ -667,9 +679,27 @@ CORTICAL_THICKNESS_IMAGE=${OUTPUT_PREFIX}CorticalThickness.${OUTPUT_SUFFIX}
 # Brain extraction
 #
 ################################################################################
-
+EXTRACTED_SEGMENTATION_BRAIN=${OUTPUT_PREFIX}BrainExtractionBrain.${OUTPUT_SUFFIX}
+EXTRACTION_GENERIC_AFFINE=${OUTPUT_PREFIX}BrainExtractionPrior0GenericAffine.mat
+EXTRACTED_BRAIN_TEMPLATE=${OUTPUT_PREFIX}ExtractedTemplateBrain.${OUTPUT_SUFFIX}
+if [[ ! -s ${OUTPUT_PREFIX}ACTStage1Complete.txt ]]; then
+if [[ ${ACT_STAGE} -eq 0 ]] || [[ ${ACT_STAGE} -eq 1  ]] ; then # BAStages bxt
 if [[ ! -f ${BRAIN_EXTRACTION_MASK} ]];
   then
+
+    if [[ ! -f ${BRAIN_TEMPLATE} ]];
+      then
+        echo "The extraction template doesn't exist:"
+        echo "   $BRAIN_TEMPLATE"
+        exit 1
+      fi
+    if [[ ! -f ${EXTRACTION_PRIOR} ]];
+      then
+        echo "The brain extraction prior doesn't exist:"
+        echo "   $EXTRACTION_PRIOR"
+        exit 1
+      fi
+
     if [[ -f ${EXTRACTION_REGISTRATION_MASK} ]]
       then
         logCmd ${ANTSPATH}/antsBrainExtraction.sh \
@@ -700,35 +730,34 @@ if [[ ! -f ${BRAIN_EXTRACTION_MASK} ]];
 
   fi
 
-EXTRACTED_SEGMENTATION_BRAIN=${OUTPUT_PREFIX}BrainExtractionBrain.${OUTPUT_SUFFIX}
 if [[ ! -f ${EXTRACTED_SEGMENTATION_BRAIN} ]];
   then
     logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${EXTRACTED_SEGMENTATION_BRAIN} m ${ANATOMICAL_IMAGES[0]} ${BRAIN_EXTRACTION_MASK}
   fi
 
-EXTRACTION_GENERIC_AFFINE=${OUTPUT_PREFIX}BrainExtractionPrior0GenericAffine.mat
-EXTRACTED_BRAIN_TEMPLATE=${OUTPUT_PREFIX}ExtractedTemplateBrain.${OUTPUT_SUFFIX}
-if [[ ! -f ${EXTRACTED_BRAIN_TEMPLATE} ]];
+if [[ -f ${BRAIN_TEMPLATE} ]] && [[ ! -f ${EXTRACTED_BRAIN_TEMPLATE} ]];
   then
     logCmd ${ANTSPATH}/ThresholdImage ${DIMENSION} ${EXTRACTION_PRIOR} ${EXTRACTED_BRAIN_TEMPLATE} 0.1 1.01 1 0
     logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${EXTRACTED_BRAIN_TEMPLATE} m ${BRAIN_TEMPLATE} ${EXTRACTED_BRAIN_TEMPLATE}
   fi
+echo ${OUTPUT_PREFIX}ACTStage1Complete.txt > ${OUTPUT_PREFIX}ACTStage1Complete.txt
+fi # BAStages
+fi # check completion
 
 ################################################################################
 #
 # Brain segmentation
 #
 ################################################################################
-
 SEGMENTATION_WARP=${SEGMENTATION_WARP_OUTPUT_PREFIX}1Warp.nii.gz
 SEGMENTATION_INVERSE_WARP=${SEGMENTATION_WARP_OUTPUT_PREFIX}1InverseWarp.nii.gz
 SEGMENTATION_GENERIC_AFFINE=${SEGMENTATION_WARP_OUTPUT_PREFIX}0GenericAffine.mat
 SEGMENTATION_MASK_DILATED=${BRAIN_SEGMENTATION_OUTPUT}MaskDilated.nii.gz
 SEGMENTATION_CONVERGENCE_FILE=${BRAIN_SEGMENTATION_OUTPUT}Convergence.txt
 
-if [[ ! -f ${BRAIN_SEGMENTATION} ]];
-  then
-
+if [[ ! -s ${OUTPUT_PREFIX}ACTStage2Complete.txt ]]  && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage1Complete.txt ]]; then
+  if [[ ${ACT_STAGE} -eq 0 ]] || [[ ${ACT_STAGE} -eq 2  ]] ; then # BAStages reg
     echo
     echo "--------------------------------------------------------------------------------------"
     echo " Brain segmentation using the following steps:"
@@ -738,106 +767,145 @@ if [[ ! -f ${BRAIN_SEGMENTATION} ]];
     echo "--------------------------------------------------------------------------------------"
     echo
 
-    # Check inputs
-    if [[ ! -f ${EXTRACTED_BRAIN_TEMPLATE} ]];
-      then
-        echo "The segmentation template doesn't exist:"
-        echo "   ${EXTRACTED_BRAIN_TEMPLATE}"
-        exit 1
-      fi
-    if [[ ! -f ${EXTRACTED_SEGMENTATION_BRAIN} ]];
-      then
-        echo "The extracted brain doesn't exist:"
-        echo "   ${EXTRACTED_SEGMENTATION_BRAIN}"
-        exit 1
-      fi
+    time_start_brain_registration=`date +%s`
 
-    time_start_brain_segmentation=`date +%s`
-
-
-    TMP_FILES=()
-    ## Step 1 ##
-    if [[ ! -f ${SEGMENTATION_WARP} ]];
-      then
-        logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${SEGMENTATION_MASK_DILATED} MD ${BRAIN_EXTRACTION_MASK} 20
-
-        basecall=''
-        if [[ ${RUN_QUICK} -ne 0 ]];
-          then
-            TMP_FILES=( ${TMP_FILES[@]} "${SEGMENTATION_WARP_OUTPUT_PREFIX}Warped.nii.gz" )
-
-            basecall="${ANTSPATH}/antsRegistrationSyNQuick.sh -d ${DIMENSION} -f ${EXTRACTED_SEGMENTATION_BRAIN}"
-            basecall="${basecall} -m ${EXTRACTED_BRAIN_TEMPLATE} -o ${SEGMENTATION_WARP_OUTPUT_PREFIX} -j 1"
-            if [[ ${USE_FLOAT_PRECISION} -ne 0 ]];
-              then
-                basecall="${basecall} -p f"
-              fi
-        else
-          basecall="${ANTS} -d ${DIMENSION} -u 1 -w [0.01,0.99] -o ${SEGMENTATION_WARP_OUTPUT_PREFIX} --float ${USE_FLOAT_PRECISION}"
-          IMAGES="${EXTRACTED_SEGMENTATION_BRAIN},${EXTRACTED_BRAIN_TEMPLATE}"
-          if [[ -f ${EXTRACTION_GENERIC_AFFINE} ]];
-            then
-              basecall="${basecall} -r [${EXTRACTION_GENERIC_AFFINE},1]"
-            else
-              basecall="${basecall} -r [${IMAGES},1]"
-            fi
-          basecall="${basecall} -x [${SEGMENTATION_MASK_DILATED}]"
-          stage1="-m MI[${IMAGES},${ANTS_LINEAR_METRIC_PARAMS}] -c ${ANTS_LINEAR_CONVERGENCE} -t Affine[0.1] -f 8x4x2x1 -s 4x2x1x0"
-          stage2="-m CC[${IMAGES},1,4] -c [${ANTS_MAX_ITERATIONS},1e-9,15] -t ${ANTS_TRANSFORMATION} -f 6x4x2x1 -s 3x2x1x0"
-
-          basecall="${basecall} ${stage1} ${stage2}"
-        fi
-
-        exe_brain_segmentation_1=${basecall}
-
-
-        # Precision errors in .nii (which stores things as float) headers can cause problems, so attempt to make everything consistent.
-        # Won't be perfectly consistent because we don't change ${ANATOMICAL_IMAGES[0]} and CopyImageHeaderInformation does not make
-        # a perfect copy. But hopefully close enough
-        for img in ${BRAIN_EXTRACTION_MASK} ${EXTRACTED_SEGMENTATION_BRAIN} ${SEGMENTATION_MASK_DILATED};
-          do
-            logCmd ${ANTSPATH}/CopyImageHeaderInformation ${ANATOMICAL_IMAGES[0]} ${img} ${img} 1 1 1
-          done
-
-        logCmd $exe_brain_segmentation_1
-
-      fi
-
-    ## check to see if the output registration transforms exist
-    if [[ ! -f ${SEGMENTATION_GENERIC_AFFINE} ]];
-      then
-        echo "The registration component of the segmentation step didn't complete properly."
-        echo "The transform file ${SEGMENTATION_GENERIC_AFFINE} does not exist."
-        exit 1
-      fi
-
-    if [[ ! -f ${SEGMENTATION_WARP} ]];
-      then
-        echo "The registration component of the segmentation step didn't complete properly."
-        echo "The transform file ${SEGMENTATION_WARP} does not exist."
-        exit 1
-      fi
-
-    ## Step 2 ##
+    # Check to see if the warped priors exist.  If so, we don't need to warp
+    # the template and priors to the individual subject.
 
+    WARPED_PRIORS_ALREADY_EXIST=1;
     for (( i = 0; i < ${NUMBER_OF_PRIOR_IMAGES}; i++ ))
       do
-        if [[ ! -f ${PRIOR_IMAGE_FILENAMES[$i]} ]];
+        if [[ ! -f ${WARPED_PRIOR_IMAGE_FILENAMES[$i]} ]];
           then
-            echo "The prior image file name does not exist:"
-            echo "   ${PRIOR_IMAGE_FILENAMES[$i]}"
+            WARPED_PRIORS_ALREADY_EXIST=0
+            break
+          fi
+      done
+
+    TMP_FILES=()
+
+    if [[ $WARPED_PRIORS_ALREADY_EXIST -eq 0 ]]
+      then
+
+      # Check inputs
+      if [[ ! -f ${EXTRACTED_BRAIN_TEMPLATE} ]];
+        then
+          echo "The segmentation template doesn't exist:"
+          echo "   ${EXTRACTED_BRAIN_TEMPLATE}"
+          rm -f ${OUTPUT_PREFIX}ACTStage1Complete.txt
+          exit 1
+        fi
+      if [[ ! -f ${EXTRACTED_SEGMENTATION_BRAIN} ]];
+        then
+          echo "The extracted brain doesn't exist:"
+          echo "   ${EXTRACTED_SEGMENTATION_BRAIN}"
+          rm -f ${OUTPUT_PREFIX}ACTStage1Complete.txt
+          exit 1
+        fi
+      if [[ ! -f ${BRAIN_EXTRACTION_MASK} ]];
+        then
+          echo "The brain extraction mask does not exist:"
+          echo "   ${BRAIN_EXTRACTION_MASK}"
+          rm -f ${OUTPUT_PREFIX}ACTStage1Complete.txt
+          exit 1
+        fi
+
+        if [[ ! -f ${SEGMENTATION_WARP} ]];
+          then
+            logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${SEGMENTATION_MASK_DILATED} MD ${BRAIN_EXTRACTION_MASK} 20
+
+            basecall=''
+            if [[ ${RUN_QUICK} -ne 0 ]];
+              then
+                TMP_FILES=( ${TMP_FILES[@]} "${SEGMENTATION_WARP_OUTPUT_PREFIX}Warped.nii.gz" "${SEGMENTATION_WARP_OUTPUT_PREFIX}InverseWarped.nii.gz" )
+
+                basecall="${ANTSPATH}/antsRegistrationSyNQuick.sh -d ${DIMENSION} -f ${EXTRACTED_SEGMENTATION_BRAIN}"
+                basecall="${basecall} -m ${EXTRACTED_BRAIN_TEMPLATE} -o ${SEGMENTATION_WARP_OUTPUT_PREFIX} -j 1"
+                if [[ ${USE_FLOAT_PRECISION} -ne 0 ]];
+                  then
+                    basecall="${basecall} -p f"
+                  fi
+            else
+              basecall="${ANTS} -d ${DIMENSION} -u 1 -w [0.01,0.99] -o ${SEGMENTATION_WARP_OUTPUT_PREFIX} --float ${USE_FLOAT_PRECISION} --verbose 1"
+              IMAGES="${EXTRACTED_SEGMENTATION_BRAIN},${EXTRACTED_BRAIN_TEMPLATE}"
+              if [[ -f ${EXTRACTION_GENERIC_AFFINE} ]];
+                then
+                  basecall="${basecall} -r [${EXTRACTION_GENERIC_AFFINE},1]"
+                else
+                  basecall="${basecall} -r [${IMAGES},1]"
+                fi
+              basecall="${basecall} -x [${SEGMENTATION_MASK_DILATED}]"
+              stage1="-m MI[${IMAGES},${ANTS_LINEAR_METRIC_PARAMS}] -c ${ANTS_LINEAR_CONVERGENCE} -t Affine[0.1] -f 8x4x2x1 -s 4x2x1x0"
+              stage2="-m CC[${IMAGES},1,4] -c [${ANTS_MAX_ITERATIONS},1e-9,15] -t ${ANTS_TRANSFORMATION} -f 6x4x2x1 -s 3x2x1x0"
+
+              basecall="${basecall} ${stage1} ${stage2}"
+            fi
+
+            exe_brain_segmentation_1=${basecall}
+
+
+            # Precision errors in .nii (which stores things as float) headers can cause problems, so attempt to make everything consistent.
+            # Won't be perfectly consistent because we don't change ${ANATOMICAL_IMAGES[0]} and CopyImageHeaderInformation does not make
+            # a perfect copy. But hopefully close enough
+            for img in ${BRAIN_EXTRACTION_MASK} ${EXTRACTED_SEGMENTATION_BRAIN} ${SEGMENTATION_MASK_DILATED};
+              do
+                logCmd ${ANTSPATH}/CopyImageHeaderInformation ${ANATOMICAL_IMAGES[0]} ${img} ${img} 1 1 1
+              done
+
+            logCmd $exe_brain_segmentation_1
+
+          fi
+
+        ## check to see if the output registration transforms exist
+        if [[ ! -f ${SEGMENTATION_GENERIC_AFFINE} ]];
+          then
+            echo "The registration component of the segmentation step didn't complete properly."
+            echo "The transform file ${SEGMENTATION_GENERIC_AFFINE} does not exist."
             exit 1
           fi
 
-        exe_brain_segmentation_2="${WARP} -d ${DIMENSION} -i ${PRIOR_IMAGE_FILENAMES[$i]} -o ${WARPED_PRIOR_IMAGE_FILENAMES[$i]} -r ${ANATOMICAL_IMAGES[0]} -n Gaussian  -t ${SEGMENTATION_WARP} -t ${SEGMENTATION_GENERIC_AFFINE} --float ${USE_FLOAT_PRECISION}"
+        if [[ ! -f ${SEGMENTATION_WARP} ]];
+          then
+            echo "The registration component of the segmentation step didn't complete properly."
+            echo "The transform file ${SEGMENTATION_WARP} does not exist."
+            exit 1
+          fi
 
-        logCmd $exe_brain_segmentation_2
-      done
+        ## Step 2 ##
 
-    # We do two stages of antsAtroposN4.  The first stage is to get a good N4
-    # bias corrected image(s).  This bias corrected image(s) is used as input to the
-    # second stage where we only do 2 iterations.
+        for (( i = 0; i < ${NUMBER_OF_PRIOR_IMAGES}; i++ ))
+          do
+            if [[ ! -f ${PRIOR_IMAGE_FILENAMES[$i]} ]];
+              then
+                echo "The prior image file name does not exist:"
+                echo "   ${PRIOR_IMAGE_FILENAMES[$i]}"
+                exit 1
+              fi
 
+            exe_brain_segmentation_2="${WARP} -d ${DIMENSION} -i ${PRIOR_IMAGE_FILENAMES[$i]} -o ${WARPED_PRIOR_IMAGE_FILENAMES[$i]} -r ${ANATOMICAL_IMAGES[0]} -n Gaussian  -t ${SEGMENTATION_WARP} -t ${SEGMENTATION_GENERIC_AFFINE} --float ${USE_FLOAT_PRECISION} --verbose 1"
+
+            logCmd $exe_brain_segmentation_2
+          done
+      fi
+      echo ${OUTPUT_PREFIX}ACTStage2Complete.txt > ${OUTPUT_PREFIX}ACTStage2Complete.txt
+      time_end_brain_registration=`date +%s`
+      time_elapsed_brain_registration=$((time_end_brain_registration - time_start_brain_registration))
+      echo
+      echo "--------------------------------------------------------------------------------------"
+      echo " Done with brain registration:  $(( time_elapsed_brain_segmentation / 3600 ))h $(( time_elapsed_brain_registration %3600 / 60 ))m $(( time_elapsed_brain_registration % 60 ))s"
+      echo "--------------------------------------------------------------------------------------"
+      echo
+    fi # BAStages check reg
+  fi # BAStages check reg
+
+# We do two stages of antsAtroposN4.  The first stage is to get a good N4
+# bias corrected image(s).  This bias corrected image(s) is used as input to the
+# second stage where we only do 2 iterations.
+if [[ ! -s ${OUTPUT_PREFIX}ACTStage3Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage2Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage1Complete.txt ]] ; then
+  if [[ ${ACT_STAGE} -eq 0 ]] || [[ ${ACT_STAGE} -eq 3  ]] ; then # BAStages seg
+    time_start_brain_segmentation=`date +%s`
     ATROPOS_ANATOMICAL_IMAGES_COMMAND_LINE='';
     for (( j = 0; j < ${#ANATOMICAL_IMAGES[@]}; j++ ))
       do
@@ -865,13 +933,14 @@ if [[ ! -f ${BRAIN_SEGMENTATION} ]];
       ${ATROPOS_LABEL_PROPAGATION_COMMAND_LINE} \
       -x ${BRAIN_EXTRACTION_MASK} \
       -m ${ATROPOS_SEGMENTATION_NUMBER_OF_ITERATIONS} \
-      -n 5 \
+      -n ${ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS} \
       -c ${NUMBER_OF_PRIOR_IMAGES} \
       ${N4_INCLUDE_PRIORS_COMMAND_LINE} \
       -p ${SEGMENTATION_PRIOR_WARPED} \
       -w ${ATROPOS_SEGMENTATION_PRIOR_WEIGHT} \
       -o ${OUTPUT_PREFIX}Brain \
       -u ${USE_RANDOM_SEEDING} \
+      -g ${DENOISE_ANATOMICAL_IMAGES} \
       -k ${KEEP_TMP_IMAGES} \
       -s ${OUTPUT_SUFFIX} \
       -z ${DEBUG_MODE}
@@ -889,13 +958,14 @@ if [[ ! -f ${BRAIN_SEGMENTATION} ]];
       ${ATROPOS_LABEL_PROPAGATION_COMMAND_LINE} \
       -x ${BRAIN_EXTRACTION_MASK} \
       -m 2 \
-      -n 5 \
+      -n ${ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS} \
       -c ${NUMBER_OF_PRIOR_IMAGES} \
       ${N4_INCLUDE_PRIORS_COMMAND_LINE} \
       -p ${SEGMENTATION_PRIOR_WARPED} \
       -w ${ATROPOS_SEGMENTATION_PRIOR_WEIGHT} \
       -o ${OUTPUT_PREFIX}Brain \
       -u ${USE_RANDOM_SEEDING} \
+      -g ${DENOISE_ANATOMICAL_IMAGES} \
       -k ${KEEP_TMP_IMAGES} \
       -s ${OUTPUT_SUFFIX} \
       -z ${DEBUG_MODE}
@@ -914,7 +984,7 @@ if [[ ! -f ${BRAIN_SEGMENTATION} ]];
           do
             if [[ -e $f ]];
           then
-            logCmd rm $f
+            logCmd rm -f $f
           else
             echo "WARNING: expected temp file doesn't exist: $f"
           fi
@@ -931,8 +1001,9 @@ if [[ ! -f ${BRAIN_SEGMENTATION} ]];
     echo "--------------------------------------------------------------------------------------"
     echo
 
-   fi
-
+   echo ${OUTPUT_PREFIX}ACTStage3Complete.txt > ${OUTPUT_PREFIX}ACTStage3Complete.txt
+  fi
+fi # BAStages seg
 
 ################################################################################
 #
@@ -952,22 +1023,27 @@ REGISTRATION_SUBJECT_OUTPUT_PREFIX=${OUTPUT_PREFIX}TemplateToSubject
 REGISTRATION_SUBJECT_GENERIC_AFFINE=${REGISTRATION_SUBJECT_OUTPUT_PREFIX}1GenericAffine.mat
 REGISTRATION_SUBJECT_WARP=${REGISTRATION_SUBJECT_OUTPUT_PREFIX}0Warp.${OUTPUT_SUFFIX}
 
+# Use first N4 corrected segmentation image, which we assume to be T1
+HEAD_N4_IMAGE=${OUTPUT_PREFIX}BrainSegmentation0N4.${OUTPUT_SUFFIX}
+EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE=${OUTPUT_PREFIX}ExtractedBrain0N4.nii.gz
+
+if [[ ! -s ${OUTPUT_PREFIX}ACTStage4Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage3Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage2Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage1Complete.txt ]] ; then
+if [[ ${ACT_STAGE} -eq 0 ]] || [[ ${ACT_STAGE} -eq 4 ]] ; then # BAStages reg
+
 if [[ -f ${REGISTRATION_TEMPLATE} ]] && [[ ! -f $REGISTRATION_LOG_JACOBIAN ]];
   then
 
     TMP_FILES=()
 
-    # Use first N4 corrected segmentation image, which we assume to be T1
-    HEAD_N4_IMAGE=${OUTPUT_PREFIX}BrainSegmentation0N4.${OUTPUT_SUFFIX}
-
     echo
     echo "--------------------------------------------------------------------------------------"
     echo " Registration brain masked ${HEAD_N4_IMAGE} to ${REGISTRATION_TEMPLATE} "
     echo "--------------------------------------------------------------------------------------"
     echo
 
-    EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE=${OUTPUT_PREFIX}ExtractedBrain0N4.nii.gz
-
     logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE} m ${HEAD_N4_IMAGE} ${BRAIN_EXTRACTION_MASK}
 
     TMP_FILES=( ${TMP_FILES[@]} ${EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE} )
@@ -977,7 +1053,7 @@ if [[ -f ${REGISTRATION_TEMPLATE} ]] && [[ ! -f $REGISTRATION_LOG_JACOBIAN ]];
     basecall=''
     if [[ ${RUN_QUICK} -ne 0 ]];
       then
-        TMP_FILES=( ${TMP_FILES[@]} "${REGISTRATION_TEMPLATE_OUTPUT_PREFIX}Warped.nii.gz" )
+        TMP_FILES=( ${TMP_FILES[@]} "${REGISTRATION_TEMPLATE_OUTPUT_PREFIX}Warped.nii.gz" "${REGISTRATION_TEMPLATE_OUTPUT_PREFIX}InverseWarped.nii.gz" )
 
         basecall="${ANTSPATH}/antsRegistrationSyNQuick.sh -d ${DIMENSION} -f ${REGISTRATION_TEMPLATE}"
         basecall="${basecall} -m ${EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE} -o ${REGISTRATION_TEMPLATE_OUTPUT_PREFIX} -j 1"
@@ -987,7 +1063,7 @@ if [[ -f ${REGISTRATION_TEMPLATE} ]] && [[ ! -f $REGISTRATION_LOG_JACOBIAN ]];
           fi
       else
         IMAGES="${REGISTRATION_TEMPLATE},${EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE}"
-        basecall="${ANTS} -d ${DIMENSION} -u 1 -w [0.01,0.99] -o ${REGISTRATION_TEMPLATE_OUTPUT_PREFIX} -r [${IMAGES},1] --float ${USE_FLOAT_PRECISION}"
+        basecall="${ANTS} -d ${DIMENSION} -v 1 -u 1 -w [0.01,0.99] -o ${REGISTRATION_TEMPLATE_OUTPUT_PREFIX} -r [${IMAGES},1] --float ${USE_FLOAT_PRECISION}"
         stage1="-m MI[${IMAGES},${ANTS_LINEAR_METRIC_PARAMS}] -c ${ANTS_LINEAR_CONVERGENCE} -t Rigid[0.1] -f 8x4x2x1 -s 3x2x1x0"
         stage2="-m MI[${IMAGES},${ANTS_LINEAR_METRIC_PARAMS}] -c ${ANTS_LINEAR_CONVERGENCE} -t Affine[0.1] -f 8x4x2x1 -s 3x2x1x0"
         stage3="-m CC[${IMAGES},1,4] -c [${ANTS_MAX_ITERATIONS},1e-9,15] -t ${ANTS_TRANSFORMATION} -f 6x4x2x1 -s 3x2x1x0"
@@ -1023,7 +1099,7 @@ if [[ -f ${REGISTRATION_TEMPLATE} ]] && [[ ! -f $REGISTRATION_LOG_JACOBIAN ]];
       echo "The transform file ${REGISTRATION_SUBJECT_WARP} does not exist."
       exit 1
     fi
-    logCmd ${ANTSPATH}/antsApplyTransforms -d ${DIMENSION} -o Linear[$REGISTRATION_SUBJECT_GENERIC_AFFINE,1] -t $REGISTRATION_TEMPLATE_GENERIC_AFFINE
+    logCmd ${ANTSPATH}/antsApplyTransforms -d ${DIMENSION} -o Linear[$REGISTRATION_SUBJECT_GENERIC_AFFINE,1] -t $REGISTRATION_TEMPLATE_GENERIC_AFFINE --verbose 1
 
     time_end_template_registration=`date +%s`
     time_elapsed_template_registration=$((time_end_template_registration - time_start_template_registration))
@@ -1039,17 +1115,20 @@ if [[ -f ${REGISTRATION_TEMPLATE} ]] && [[ ! -f $REGISTRATION_LOG_JACOBIAN ]];
         for f in ${TMP_FILES[@]}
           do
             if [[ -e $f ]];
-             then
-              logCmd rm $f
-            else
-              echo "WARNING: expected temp file doesn't exist: $f"
-            fi
-        done
+              then
+                logCmd rm -f $f
+              else
+                echo "WARNING: expected temp file doesn't exist: $f"
+              fi
+          done
       fi
+  logCmd ${ANTSPATH}/CreateJacobianDeterminantImage ${DIMENSION} ${REGISTRATION_TEMPLATE_WARP} ${REGISTRATION_LOG_JACOBIAN} 1 1
   fi # if registration template & jacobian check
-
-
-
+  if [[ -s ${REGISTRATION_LOG_JACOBIAN} ]] ; then
+    echo ${OUTPUT_PREFIX}ACTStage4Complete.txt > ${OUTPUT_PREFIX}ACTStage4Complete.txt
+  fi
+fi # BAStages
+fi # check completion
 
 ################################################################################
 #
@@ -1067,6 +1146,11 @@ CORTICAL_THICKNESS_SEGMENTATION=${OUTPUT_PREFIX}CorticalThicknessSegmentation.${
 CORTICAL_THICKNESS_GM_SEGMENTATION=${OUTPUT_PREFIX}CorticalThicknessGMSegmentation.${OUTPUT_SUFFIX}
 CORTICAL_LABEL_THICKNESS_PRIOR=${OUTPUT_PREFIX}CorticalLabelThicknessPrior.${OUTPUT_SUFFIX}
 
+if [[ ! -s ${OUTPUT_PREFIX}ACTStage5Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage3Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage2Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage1Complete.txt ]] ; then
+if [[ ${ACT_STAGE} -eq 0 ]] || [[ ${ACT_STAGE} -eq 5  ]] ; then # BAStages thk
 if [[ ! -f ${CORTICAL_THICKNESS_IMAGE} ]];
   then
 
@@ -1136,7 +1220,7 @@ if [[ ! -f ${CORTICAL_THICKNESS_IMAGE} ]];
 
     TMP_FILES=( $CORTICAL_THICKNESS_GM $CORTICAL_THICKNESS_WM $CORTICAL_THICKNESS_SEGMENTATION )
 
-    exe_direct="${DIRECT} -d ${DIMENSION} -s [${CORTICAL_THICKNESS_SEGMENTATION},${GRAY_MATTER_LABEL},${WHITE_MATTER_LABEL}]"
+    exe_direct="${DIRECT} -d ${DIMENSION} -s [${CORTICAL_THICKNESS_SEGMENTATION},${GRAY_MATTER_LABEL},${WHITE_MATTER_LABEL}] --verbose 1"
     exe_direct="${exe_direct} -g ${CORTICAL_THICKNESS_GM} -w ${CORTICAL_THICKNESS_WM} -o ${CORTICAL_THICKNESS_IMAGE}"
     exe_direct="${exe_direct} -c ${DIRECT_CONVERGENCE} -r ${DIRECT_GRAD_STEP_SIZE}"
     exe_direct="${exe_direct} -m ${DIRECT_SMOOTHING_PARAMETER} -n ${DIRECT_NUMBER_OF_DIFF_COMPOSITIONS} -b ${USE_BSPLINE_SMOOTHING}"
@@ -1149,7 +1233,7 @@ if [[ ! -f ${CORTICAL_THICKNESS_IMAGE} ]];
 #        logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${CORTICAL_LABEL_THICKNESS_PRIOR} m ${CORTICAL_LABEL_THICKNESS_PRIOR} 2.0
 
     	   logCmd ${ANTSPATH}/antsApplyTransforms -d ${DIMENSION} -i ${CORTICAL_LABEL_IMAGE} -o ${CORTICAL_LABEL_THICKNESS_PRIOR} \
-	         -t $REGISTRATION_SUBJECT_GENERIC_AFFINE -t $REGISTRATION_SUBJECT_WARP -r  ${ANATOMICAL_IMAGES[0]}
+	         -t $REGISTRATION_SUBJECT_GENERIC_AFFINE -t $REGISTRATION_SUBJECT_WARP -r ${ANATOMICAL_IMAGES[0]} --verbose 1
 
         exe_direct="${exe_direct} -a ${CORTICAL_LABEL_THICKNESS_PRIOR}"
 
@@ -1166,7 +1250,7 @@ if [[ ! -f ${CORTICAL_THICKNESS_IMAGE} ]];
           do
             if [[ -e $f ]];
               then
-                logCmd rm $f
+                logCmd rm -f $f
               else
                 echo "WARNING: expected temp file doesn't exist: $f"
               fi
@@ -1190,17 +1274,27 @@ if [[ ! -f ${CORTICAL_THICKNESS_IMAGE} ]];
     echo
 
   fi
-
+  echo ${OUTPUT_PREFIX}ACTStage5Complete.txt > ${OUTPUT_PREFIX}ACTStage5Complete.txt
+fi # BAStages
+fi # check completion
 
 #### BA Edits Begin ####
+if [[ ! -s ${OUTPUT_PREFIX}ACTStage6Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage5Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage3Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage2Complete.txt ]] && \
+   [[   -s ${OUTPUT_PREFIX}ACTStage1Complete.txt ]] ; then
+if [[ ${ACT_STAGE} -eq 0 ]] || [[ ${ACT_STAGE} -eq 6  ]] ; then # BAStages qc
 echo "--------------------------------------------------------------------------------------"
 echo "Compute summary measurements"
 echo "--------------------------------------------------------------------------------------"
-
+if [[ ! -s ${OUTPUT_PREFIX}CorticalThickness.nii.gz ]] ; then
+  echo ${OUTPUT_PREFIX}CorticalThickness.nii.gz incomplete!
+  exit 1
+fi
 if [[ -f ${REGISTRATION_TEMPLATE_WARP} ]];
   then
-    logCmd ${ANTSPATH}/CreateJacobianDeterminantImage ${DIMENSION} ${REGISTRATION_TEMPLATE_WARP} ${REGISTRATION_LOG_JACOBIAN} 1 1
-    exe_template_registration_3="${WARP} -d ${DIMENSION} -i ${CORTICAL_THICKNESS_IMAGE} -o ${OUTPUT_PREFIX}CorticalThicknessNormalizedToTemplate.${OUTPUT_SUFFIX} -r ${REGISTRATION_TEMPLATE} -n Gaussian  -t ${REGISTRATION_TEMPLATE_WARP}  -t ${REGISTRATION_TEMPLATE_GENERIC_AFFINE} --float ${USE_FLOAT_PRECISION}"
+    exe_template_registration_3="${WARP} -d ${DIMENSION} -i ${CORTICAL_THICKNESS_IMAGE} -o ${OUTPUT_PREFIX}CorticalThicknessNormalizedToTemplate.${OUTPUT_SUFFIX} -r ${REGISTRATION_TEMPLATE} -n Gaussian  -t ${REGISTRATION_TEMPLATE_WARP}  -t ${REGISTRATION_TEMPLATE_GENERIC_AFFINE} --float ${USE_FLOAT_PRECISION} --verbose 1"
     logCmd $exe_template_registration_3
 
     EXTRACTED_SEGMENTATION_BRAIN_DEFORMED=${OUTPUT_PREFIX}BrainNormalizedToTemplate.${OUTPUT_SUFFIX}
@@ -1215,14 +1309,14 @@ if [[ -f ${REGISTRATION_TEMPLATE_WARP} ]];
 
     TMP_FILES=( ${TMP_FILES[@]} ${EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE} ${EXTRACTED_SEGMENTATION_BRAIN_DEFORMED} ${REGISTRATION_TEMPLATE_BRAIN_MASK} )
 
-    logCmd ${WARP} -d ${DIMENSION} -i ${EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE} -o ${EXTRACTED_SEGMENTATION_BRAIN_DEFORMED} -r ${REGISTRATION_TEMPLATE} -n Linear -t ${REGISTRATION_TEMPLATE_WARP}  -t ${REGISTRATION_TEMPLATE_GENERIC_AFFINE} --float ${USE_FLOAT_PRECISION}
+    logCmd ${WARP} -d ${DIMENSION} -i ${EXTRACTED_SEGMENTATION_BRAIN_N4_IMAGE} -o ${EXTRACTED_SEGMENTATION_BRAIN_DEFORMED} -r ${REGISTRATION_TEMPLATE} -n Linear -t ${REGISTRATION_TEMPLATE_WARP}  -t ${REGISTRATION_TEMPLATE_GENERIC_AFFINE} --float ${USE_FLOAT_PRECISION} --verbose 1
   fi
 
 ccmetric=`${ANTSPATH}/ImageMath ${DIMENSION} a PearsonCorrelation ${REGISTRATION_TEMPLATE} ${EXTRACTED_SEGMENTATION_BRAIN_DEFORMED} ${REGISTRATION_TEMPLATE_BRAIN_MASK}`
-bvol=`${ANTSPATH}/ImageMath ${DIMENSION} a total ${BRAIN_EXTRACTION_MASK}  | cut -d ':' -f 2 | cut -d ' ' -f 2 `
-gvol=`${ANTSPATH}/ImageMath ${DIMENSION} a total ${BRAIN_SEGMENTATION_GM}  | cut -d ':' -f 2 | cut -d ' ' -f 2 `
-wvol=`${ANTSPATH}/ImageMath ${DIMENSION} a total ${BRAIN_SEGMENTATION_WM}  | cut -d ':' -f 2 | cut -d ' ' -f 2 `
-thks=`${ANTSPATH}/ImageMath ${DIMENSION} a total $CORTICAL_THICKNESS_IMAGE | cut -d ':' -f 2 | cut -d ' ' -f 2 `
+bvol=`${ANTSPATH}/ImageMath ${DIMENSION} a total ${BRAIN_EXTRACTION_MASK}  | cut -d ':' -f 3 | cut -d ' ' -f 2 `
+gvol=`${ANTSPATH}/ImageMath ${DIMENSION} a total ${BRAIN_SEGMENTATION_GM}  | cut -d ':' -f 3 | cut -d ' ' -f 2 `
+wvol=`${ANTSPATH}/ImageMath ${DIMENSION} a total ${BRAIN_SEGMENTATION_WM}  | cut -d ':' -f 3 | cut -d ' ' -f 2 `
+thks=`${ANTSPATH}/ImageMath ${DIMENSION} a total ${CORTICAL_THICKNESS_IMAGE} | cut -d ':' -f 3 | cut -d ' ' -f 2 `
 echo "PearsonCorrelation,BVOL,GVol,WVol,ThicknessSum" >   ${OUTPUT_PREFIX}brainvols.csv
 echo "${ccmetric},${bvol},${gvol},${wvol},${thks}" >>  ${OUTPUT_PREFIX}brainvols.csv
 if [[ -f ${ANTSPATH}/GetMeshAndTopology ]] && [[ ${DIMENSION} -eq 3 ]] ; then
@@ -1232,7 +1326,7 @@ if [[ -f ${ANTSPATH}/GetMeshAndTopology ]] && [[ ${DIMENSION} -eq 3 ]] ; then
   ${ANTSPATH}/ImageMath ${DIMENSION} ${OUTPUT_PREFIX}temp.nii.gz MD ${OUTPUT_PREFIX}temp.nii.gz 2
   ${ANTSPATH}/SmoothImage 3 ${CORTICAL_THICKNESS_IMAGE} 1 ${OUTPUT_PREFIX}temp2.nii.gz
   #          ${ANTSPATH}/GetMeshAndTopology ${OUTPUT_PREFIX}temp.nii.gz ${OUTPUT_PREFIX}temp2.nii.gz ${OUTPUT_PREFIX}.vtk thickness   0.3 0.001 ${OUTPUT_PREFIX}_Thickness.png
-  rm ${OUTPUT_PREFIX}temp.nii.gz ${OUTPUT_PREFIX}temp2.nii.gz
+  rm -f ${OUTPUT_PREFIX}temp.nii.gz ${OUTPUT_PREFIX}temp2.nii.gz
 fi
 echo "--------------------------------------------------------------------------------------"
 #### BA Edits End ####
@@ -1297,7 +1391,7 @@ if [[ ! -f ${CORTICAL_THICKNESS_MOSAIC} || ! -f ${BRAIN_SEGMENTATION_MOSAIC} ]];
     logCmd $conversion
 
     mosaic="${ANTSPATH}/CreateTiledMosaic -i ${HEAD_N4_IMAGE_RESAMPLED} -r ${CORTICAL_THICKNESS_IMAGE_RGB}"
-    mosaic="${mosaic} -o ${CORTICAL_THICKNESS_MOSAIC} -a 1.0 -t -1x-1 -d 2 -p mask"
+    mosaic="${mosaic} -o ${CORTICAL_THICKNESS_MOSAIC} -a 1.0 -t -1x-1 -d z -p mask"
     mosaic="${mosaic} -s [2,mask,mask] -x ${CORTICAL_THICKNESS_MASK}"
     logCmd $mosaic
 
@@ -1323,28 +1417,32 @@ if [[ ! -f ${CORTICAL_THICKNESS_MOSAIC} || ! -f ${BRAIN_SEGMENTATION_MOSAIC} ]];
           do
             if [[ -e $f ]];
              then
-              logCmd rm $f
+              logCmd rm -f $f
             else
               echo "WARNING: expected temp file doesn't exist: $f"
             fi
         done
       fi
   fi
-
+  echo ${OUTPUT_PREFIX}ACTStage6Complete.txt > ${OUTPUT_PREFIX}ACTStage6Complete.txt
+fi # BAStages
+fi # check completion
 ################################################################################
 #
 # End of main routine
 #
 ################################################################################
 
-logCmd checkOutputExists
+if [[ ${ACT_STAGE} -eq 0 ]] || [[ ${ACT_STAGE} -ge 5  ]] ; then
+  logCmd checkOutputExists
+fi
 
 time_end=`date +%s`
 time_elapsed=$((time_end - time_start))
 
 echo
 echo "--------------------------------------------------------------------------------------"
-echo " Done with ANTs processing pipeline"
+echo " Done with ANTs processing pipeline: stage $ACT_STAGE"
 echo " Script executed in $time_elapsed seconds"
 echo " $(( time_elapsed / 3600 ))h $(( time_elapsed %3600 / 60 ))m $(( time_elapsed % 60 ))s"
 echo "--------------------------------------------------------------------------------------"
