@@ -5,7 +5,7 @@ VERSION="0.0"
 # Check dependencies
 
 PROGRAM_DEPENDENCIES=( 'antsRegistration' 'antsApplyTransforms' 'N4BiasFieldCorrection' 'Atropos' 'KellyKapowski' )
-SCRIPTS_DEPENDENCIES=( 'antsBrainExtraction.sh' 'antsAtroposN4.sh' 'antsMultivariateTemplateConstruction2.sh' 'antsMalfLabeling.sh' )
+SCRIPTS_DEPENDENCIES=( 'antsBrainExtraction.sh' 'antsAtroposN4.sh' 'antsMultivariateTemplateConstruction2.sh' 'antsJointLabelFusion.sh' )
 
 for D in ${PROGRAM_DEPENDENCIES[@]};
   do
@@ -38,7 +38,7 @@ are performed:
      b. The brain extraction SST prior is created by smoothing the brain extraction
         mask created during 2a.
      c. If labeled atlases are not provided, we smooth the posteriors from 2a to create
-        the SST segmentation priors, otherwise we use antsMalfLabeling to create a set of
+        the SST segmentation priors, otherwise we use antsJointFusion to create a set of
         posteriors (https://github.com/ntustison/antsCookTemplatePriorsExample).
   3. Using the SST + priors, we run each subject through the antsCorticalThickness
      pipeline.
@@ -104,6 +104,7 @@ Optional arguments:
                                                   2 = use PEXEC (localhost)
                                                   3 = Apple XGrid
                                                   4 = PBS qsub
+                                                  5 = SLURM
      -t:  template for t1 registration          Anatomical *intensity* template (assumed to be skull-stripped).  A common
                                                 use case would be where this would be the same template as specified in the
                                                 -e option which is not skull stripped.
@@ -111,13 +112,14 @@ Optional arguments:
                                                 aren't used then we simply smooth the single-subject template posteriors after
                                                 passing through antsCorticalThickness.sh. Example:
 
- 						  -a atlas1.nii.gz -a atlas2.nii.gz ... -a atlasN.nii.gz
+ 						                                         -a atlas1.nii.gz -a atlas2.nii.gz ... -a atlasN.nii.gz
 
      -l:                                        Labels associated with each atlas, in the same order as they are specified
 						with the -a option. The number of labels in each image is assumed to be equal
                                                 to the number of priors.
      -f:  extraction registration mask          Mask (defined in the template space) used during registration
                                                 for brain extraction.
+     -g:  denoise anatomical images             Denoise anatomical images (default = 0).
      -j:  number of cpu cores                   Number of cpu cores to use locally for pexec option (default 2; requires "-c 2")
      -k:  number of modalities                  Number of modalities used to construct the template (default 1):  For example,
                                                 if one wanted to use multiple modalities consisting of T1, T2, and FA
@@ -125,18 +127,26 @@ Optional arguments:
      -n:  use SST cortical thickness prior      If set to '1', the cortical thickness map from the single-subject template is used
                                                 as a prior constraint for each of the individual calls to antsCorticalThickness.sh
                                                 (default = 0).
-     -g:  use floating-point precision          Use floating point precision in registrations (default = 0)
+     -u:  use floating-point precision          Use floating point precision in registrations (default = 0)
      -v:  Atropos segmentation weight (SST)     Atropos spatial prior *probability* weight for the segmentation for the single
                                                 subject template (default = 0.25)
      -w:  Atropos segmentation weight (Indiv.)  Atropos spatial prior *probability* weight for the segmentation for the individual
                                                 time points (default = 0.5)
-     -q:  Use quick registration parameters     If = 1, use antsRegistrationSyNQuick.sh as the basis for registration
-                                                during brain extraction, brain segmentation, and (optional) normalization
-                                                to a template.  Otherwise use antsRegistrationSyN.sh (default = 0).
+     -x:                                        Number of iterations within Atropos (default 5).
+     -q:  Use quick registration parameters     If 'yes' then we use antsRegistrationSyNQuick.sh as the basis for registration.
+                                                Otherwise use antsRegistrationSyN.sh.  The options are as follows:
+                                                '-q 0' = antsRegistrationSyN for everything (default)
+                                                '-q 1' = Fast antsCorticalThickness to SST
+                                                '-q 2' = Fast JLF cooking
+                                                '-q 3' = Fast everything
      -r:  rigid alignment to SST                This option dictates if the individual subjects are registered to the single
                                                 subject template before running through antsCorticalThickness.  This potentially
                                                 reduces bias caused by subject orientation and voxel spacing (default = 0).
-     -z:  Test / debug mode                     If > 0, runs a faster version of the script. Only for testing. Implies -u 0.
+     -b:  keep temporary files                  Keep brain extraction/segmentation warps, etc (default = 0).
+     -y:  averge rigid transform component      Update the template with the full affine transform (default 0). If 1, the rigid
+                                                component of the affine transform will be used to update the template.
+     -z:  Test / debug mode                     If > 0, runs a faster version of the script. Only for testing. Implies -u 0
+                                                in the antsCorticalThickness.sh script (i.e., no random seeding).
                                                 Requires single thread computation for complete reproducibility.
 USAGE
     exit 1
@@ -159,11 +169,13 @@ echoParameters() {
       run quick               = ${RUN_QUICK}
       debug mode              = ${DEBUG_MODE}
       float precision         = ${USE_FLOAT_PRECISION}
+      denoise                 = ${DENOISE}
       use random seeding      = ${USE_RANDOM_SEEDING}
       number of modalities    = ${NUMBER_OF_MODALITIES}
       number of cores         = ${CORES}
       control type            = ${DOQSUB}
       rigid alignment to SST  = ${RIGID_ALIGNMENT_TO_SST}
+      average rigid component = ${AFFINE_UPDATE_FULL}
 
 PARAMETERS
 }
@@ -227,9 +239,13 @@ SEGMENTATION_PRIOR=""
 USE_SST_CORTICAL_THICKNESS_PRIOR=0
 REGISTRATION_TEMPLATE=""
 DO_REGISTRATION_TO_TEMPLATE=0
+DENOISE=0
 
 ATROPOS_SEGMENTATION_PRIOR_WEIGHT_SST=0.25
 ATROPOS_SEGMENTATION_PRIOR_WEIGHT_TIMEPOINT=0.5
+ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS=5
+
+AFFINE_UPDATE_FULL=0
 
 DOQSUB=0
 CORES=2
@@ -246,25 +262,26 @@ MALF_LABEL_STRINGS_FOR_PRIORS=()
 ################################################################################
 
 USE_FLOAT_PRECISION=0
+KEEP_TMP_IMAGES=0
 
 if [[ $# -lt 3 ]] ; then
   Usage >&2
   exit 1
 else
-  while getopts "a:b:c:d:e:f:g:h:j:k:l:m:n:o:p:q:r:s:t:v:w:z:" OPT
+  while getopts "a:b:c:d:e:f:g:h:j:k:l:m:n:o:p:q:r:s:t:u:v:x:w:y:z:" OPT
     do
       case $OPT in
           a)
        MALF_ATLASES[${#MALF_ATLASES[@]}]=$OPTARG
        ;;
-          b) # posterior formulation
-       ATROPOS_SEGMENTATION_POSTERIOR_FORMULATION=$OPTARG
+          b)
+       KEEP_TMP_IMAGES=$OPTARG
        ;;
           c)
        DOQSUB=$OPTARG
-       if [[ $DOQSUB -gt 4 ]];
+       if [[ $DOQSUB -gt 5 ]];
          then
-           echo " DOQSUB must be an integer value (0=serial, 1=SGE qsub, 2=try pexec, 3=XGrid, 4=PBS qsub ) you passed  -c $DOQSUB "
+           echo " DOQSUB must be an integer value (0=serial, 1=SGE qsub, 2=try pexec, 3=XGrid, 4=PBS qsub, 5=SLURM ) you passed  -c $DOQSUB "
            exit 1
          fi
        ;;
@@ -282,8 +299,8 @@ else
           f) #brain extraction registration mask
        EXTRACTION_REGISTRATION_MASK=$OPTARG
        ;;
-          g) #use floating point precision
-       USE_FLOAT_PRECISION=$OPTARG
+          g) #denoise
+       DENOISE=$OPTARG
        ;;
           h) #help
        Usage >&2
@@ -303,6 +320,9 @@ else
        ;;
           n) # use
        USE_SST_CORTICAL_THICKNESS_PRIOR=$OPTARG
+       ;;
+          x) #atropos segmentation internal iterations
+       ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS=$OPTARG
        ;;
           o) #output prefix
        OUTPUT_PREFIX=$OPTARG
@@ -319,12 +339,18 @@ else
        ;;
           q) # run quick
        RUN_QUICK=$OPTARG
+       ;;
+          u) #use floating point precision
+       USE_FLOAT_PRECISION=$OPTARG
        ;;
           v) #atropos prior weight for single subject template
        ATROPOS_SEGMENTATION_PRIOR_WEIGHT_SST=$OPTARG
        ;;
           w) #atropos prior weight for each individual time point
        ATROPOS_SEGMENTATION_PRIOR_WEIGHT_TIMEPOINT=$OPTARG
+       ;;
+          y) # 1 update with full affine, 0 for no rigid (default = 0)
+       AFFINE_UPDATE_FULL=$OPTARG
        ;;
           z) #debug mode
        DEBUG_MODE=$OPTARG
@@ -487,19 +513,42 @@ if [[ ${#ANATOMICAL_IMAGES[@]} -eq ${NUMBER_OF_MODALITIES} ]];
 
     # Won't be quick unless -q 3 was specified
     # But if you are running a longitudinal script without longitudinal data, that may not be the only problem
-
+    if [[ $DO_REGISTRATION_TO_TEMPLATE -eq 1 ]];
+        then
     logCmd ${ANTSPATH}/antsCorticalThickness.sh \
-      -d ${DIMENSION} \
+      -d ${DIMENSION}
+      -x ${ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS} \
+      -t ${REGISTRATION_TEMPLATE} \
       -q ${RUN_FAST_ANTSCT_TO_GROUP_TEMPLATE} \
       ${SUBJECT_ANATOMICAL_IMAGES} \
       -e ${BRAIN_TEMPLATE} \
       -f ${EXTRACTION_REGISTRATION_MASK} \
       -m ${EXTRACTION_PRIOR} \
-      -k 0 \
+      -k ${KEEP_TMP_IMAGES} \
+      -g ${DENOISE} \
       -w ${ATROPOS_SEGMENTATION_PRIOR_WEIGHT_TIMEPOINT} \
       -z ${DEBUG_MODE} \
       -p ${SEGMENTATION_PRIOR} \
       -o ${OUTPUT_PREFIX}
+    fi
+
+    if [[ $DO_REGISTRATION_TO_TEMPLATE -eq 0 ]];
+        then
+    logCmd ${ANTSPATH}/antsCorticalThickness.sh \
+      -d ${DIMENSION}
+      -x ${ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS} \
+      -q ${RUN_FAST_ANTSCT_TO_GROUP_TEMPLATE} \
+      ${SUBJECT_ANATOMICAL_IMAGES} \
+      -e ${BRAIN_TEMPLATE} \
+      -f ${EXTRACTION_REGISTRATION_MASK} \
+      -m ${EXTRACTION_PRIOR} \
+      -k ${KEEP_TMP_IMAGES} \
+      -g ${DENOISE} \
+      -w ${ATROPOS_SEGMENTATION_PRIOR_WEIGHT_TIMEPOINT} \
+      -z ${DEBUG_MODE} \
+      -p ${SEGMENTATION_PRIOR} \
+      -o ${OUTPUT_PREFIX}
+    fi
 
     exit 0
   fi
@@ -598,7 +647,7 @@ if [[ ! -f $SINGLE_SUBJECT_TEMPLATE ]];
           -r 1 \
           -s CC \
           -t GR \
-          -y 0 \
+          -y ${AFFINE_UPDATE_FULL} \
           ${TEMPLATE_Z_IMAGES} \
           ${ANATOMICAL_IMAGES[@]}
     else
@@ -622,7 +671,7 @@ if [[ ! -f $SINGLE_SUBJECT_TEMPLATE ]];
          -l 1 \
          -m CC[4] \
          -t SyN \
-         -y 0 \
+         -y ${AFFINE_UPDATE_FULL} \
          ${TEMPLATE_Z_IMAGES} \
          ${ANATOMICAL_IMAGES[@]}
     fi
@@ -637,19 +686,48 @@ if [[ ! -f ${SINGLE_SUBJECT_TEMPLATE} ]];
 
 # clean up
 
+SINGLE_SUBJECT_ANTSCT_PREFIX=${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/T_template
+
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}job*.sh
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}job*.txt
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}rigid*
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}*Repaired*
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}*WarpedToTemplate*
-logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*Warp.nii.gz
-logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*Affine.txt
-logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*GenericAffine*
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_template0warp.nii.gz
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_template0Affine.txt
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_templatewarplog.txt
 logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}initTemplateModality*.nii.gz
 
+# Also remove the warp files but we have to be careful to not remove the affine and
+# warp files generated in subsequent steps (specifically from running the SST through
+# the cortical thickness pipeline if somebody has to re-run the longitudinal pipeline
+
+if [[ -f ${SINGLE_SUBJECT_ANTSCT_PREFIX}SubjectToTemplate1Warp.nii.gz ]];
+  then
+
+    logCmd mkdir -p ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/TmpFiles/
+    logCmd mv -f ${SINGLE_SUBJECT_ANTSCT_PREFIX}SubjectToTemplate1*Warp.nii.gz \
+                 ${SINGLE_SUBJECT_ANTSCT_PREFIX}SubjectToTemplate0GenericAffine.mat \
+                 ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/TmpFiles/
+    logCmd mv -f ${SINGLE_SUBJECT_ANTSCT_PREFIX}TemplateToSubject0*Warp.nii.gz \
+                 ${SINGLE_SUBJECT_ANTSCT_PREFIX}TemplateToSubject1GenericAffine.mat \
+                 ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/TmpFiles/
+
+    logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*Warp.nii.gz
+    logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*Affine.txt
+    logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*GenericAffine*
+
+    logCmd mv -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/TmpFiles/* ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}
+    logCmd rm -rf ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/TmpFiles/
+
+  else
+
+    logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*Warp.nii.gz
+    logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*Affine.txt
+    logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}T_*GenericAffine*
+
+  fi
+
 # Need to change the number of iterations to  -q \
 
 time_end_sst_creation=`date +%s`
@@ -667,7 +745,6 @@ echo
 #
 ################################################################################
 
-SINGLE_SUBJECT_ANTSCT_PREFIX=${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/T_template
 SINGLE_SUBJECT_TEMPLATE_EXTRACTION_MASK=${SINGLE_SUBJECT_ANTSCT_PREFIX}BrainExtractionMask.${OUTPUT_SUFFIX}
 SINGLE_SUBJECT_TEMPLATE_EXTRACTION_REGISTRATION_MASK=${SINGLE_SUBJECT_ANTSCT_PREFIX}BrainExtractionRegistrationMask.${OUTPUT_SUFFIX}
 SINGLE_SUBJECT_TEMPLATE_PRIOR=${SINGLE_SUBJECT_ANTSCT_PREFIX}Priors\%${FORMAT}d.${OUTPUT_SUFFIX}
@@ -688,27 +765,29 @@ if [[ ! -f ${SINGLE_SUBJECT_TEMPLATE_CORTICAL_THICKNESS} ]];
     if [[ $DO_REGISTRATION_TO_TEMPLATE -eq 0 ]];
       then
         logCmd ${ANTSPATH}/antsCorticalThickness.sh \
-          -d ${DIMENSION} \
+          -d ${DIMENSION} -x ${ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS} \
           -q ${RUN_FAST_ANTSCT_TO_GROUP_TEMPLATE} \
           -a ${SINGLE_SUBJECT_TEMPLATE} \
           -e ${BRAIN_TEMPLATE} \
           -f ${EXTRACTION_REGISTRATION_MASK} \
+          -g ${DENOISE} \
           -m ${EXTRACTION_PRIOR} \
-          -k 0 \
+          -k ${KEEP_TMP_IMAGES} \
           -z ${DEBUG_MODE} \
           -p ${SEGMENTATION_PRIOR} \
           -w ${ATROPOS_SEGMENTATION_PRIOR_WEIGHT_SST} \
           -o ${SINGLE_SUBJECT_ANTSCT_PREFIX}
       else
         logCmd ${ANTSPATH}/antsCorticalThickness.sh \
-          -d ${DIMENSION} \
+          -d ${DIMENSION} -x ${ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS}  \
           -t ${REGISTRATION_TEMPLATE} \
           -q ${RUN_FAST_ANTSCT_TO_GROUP_TEMPLATE} \
           -a ${SINGLE_SUBJECT_TEMPLATE} \
           -e ${BRAIN_TEMPLATE} \
           -f ${EXTRACTION_REGISTRATION_MASK} \
+          -g ${DENOISE} \
           -m ${EXTRACTION_PRIOR} \
-          -k 0 \
+          -k ${KEEP_TMP_IMAGES} \
           -z ${DEBUG_MODE} \
           -p ${SEGMENTATION_PRIOR} \
           -w ${ATROPOS_SEGMENTATION_PRIOR_WEIGHT_SST} \
@@ -769,11 +848,11 @@ if [[ ${SINGLE_SUBJECT_TEMPLATE_PRIORS_EXIST} -eq 0 ]];
       else
 
         echo
-        echo "   ---> Cooking single-subject priors using antsMalfLabeling."
+        echo "   ---> Cooking single-subject priors using antsJointLabelFusion."
         echo
 
         SINGLE_SUBJECT_TEMPLATE_MALF_LABELS_PREFIX=${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_TEMPLATE}/T_template
-        SINGLE_SUBJECT_TEMPLATE_MALF_LABELS=${SINGLE_SUBJECT_TEMPLATE_MALF_LABELS_PREFIX}MalfLabels.nii.gz
+        SINGLE_SUBJECT_TEMPLATE_MALF_LABELS=${SINGLE_SUBJECT_TEMPLATE_MALF_LABELS_PREFIX}Labels.nii.gz
 
         ATLAS_AND_LABELS_STRING=''
         for (( j=0; j < ${#MALF_ATLASES[@]}; j++ ))
@@ -783,9 +862,10 @@ if [[ ${SINGLE_SUBJECT_TEMPLATE_PRIORS_EXIST} -eq 0 ]];
 
         if [[ ! -f ${SINGLE_SUBJECT_TEMPLATE_MALF_LABELS} ]];
           then
-            logCmd ${ANTSPATH}/antsMalfLabeling.sh \
+            logCmd ${ANTSPATH}/antsJointLabelFusion.sh \
               -d ${DIMENSION} \
               -q ${RUN_FAST_MALF_COOKING} \
+              -x ${SINGLE_SUBJECT_TEMPLATE_EXTRACTION_MASK} \
               -c ${DOQSUB} \
               -j ${CORES} \
               -t ${SINGLE_SUBJECT_TEMPLATE_SKULL_STRIPPED} \
@@ -880,9 +960,11 @@ for (( i=0; i < ${#ANATOMICAL_IMAGES[@]}; i+=$NUMBER_OF_MODALITIES ))
           -m ${ANATOMICAL_IMAGES[$i]} \
           -f ${SINGLE_SUBJECT_TEMPLATE} \
           -t r
+        logCmd rm -f ${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_CORTICAL_THICKNESS}/${BASENAME_ID}RigidToSSTInverseWarped.nii.gz
 
         ANATOMICAL_REFERENCE_IMAGE=${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_CORTICAL_THICKNESS}/${BASENAME_ID}RigidToSSTWarped.nii.gz
 
+
         let k=$i+$NUMBER_OF_MODALITIES
         for (( j=$i; j < $k; j++ ))
           do
@@ -916,13 +998,14 @@ for (( i=0; i < ${#ANATOMICAL_IMAGES[@]}; i+=$NUMBER_OF_MODALITIES ))
     OUTPUT_LOCAL_PREFIX=${OUTPUT_DIRECTORY_FOR_SINGLE_SUBJECT_CORTICAL_THICKNESS}/${BASENAME_ID}
 
     logCmd ${ANTSPATH}/antsCorticalThickness.sh \
-      -d ${DIMENSION} \
+      -d ${DIMENSION} -x ${ATROPOS_SEGMENTATION_INTERNAL_ITERATIONS}  \
       -q ${RUN_ANTSCT_TO_SST_QUICK} \
       ${SUBJECT_ANATOMICAL_IMAGES} \
       -e ${SINGLE_SUBJECT_TEMPLATE} \
       -m ${SINGLE_SUBJECT_TEMPLATE_EXTRACTION_PRIOR} \
       -f ${SINGLE_SUBJECT_TEMPLATE_EXTRACTION_REGISTRATION_MASK} \
-      -k 0 \
+      -g ${DENOISE} \
+      -k ${KEEP_TMP_IMAGES} \
       -z ${DEBUG_MODE} \
       -w ${ATROPOS_SEGMENTATION_PRIOR_WEIGHT_TIMEPOINT} \
       -p ${SINGLE_SUBJECT_TEMPLATE_PRIOR} \
@@ -931,23 +1014,30 @@ for (( i=0; i < ${#ANATOMICAL_IMAGES[@]}; i+=$NUMBER_OF_MODALITIES ))
 
     if [[ $DO_REGISTRATION_TO_TEMPLATE -eq 1 ]];
       then
-        logCmd ${ANTSPATH}/antsApplyTransforms \
-          -d ${DIMENSION} \
-          -r ${REGISTRATION_TEMPLATE} \
-          -o [${OUTPUT_LOCAL_PREFIX}SubjectToGroupTemplateWarp.nii.gz,1] \
-          -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}SubjectToTemplate1Warp.nii.gz \
-          -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}SubjectToTemplate0GenericAffine.mat \
-          -t ${OUTPUT_LOCAL_PREFIX}SubjectToTemplate1Warp.nii.gz \
-          -t ${OUTPUT_LOCAL_PREFIX}SubjectToTemplate0GenericAffine.mat
 
-        logCmd ${ANTSPATH}/antsApplyTransforms \
-          -d ${DIMENSION} \
-          -r ${ANATOMICAL_REFERENCE_IMAGE} \
-          -o [${OUTPUT_LOCAL_PREFIX}GroupTemplateToSubjectWarp.nii.gz,1] \
-          -t ${OUTPUT_LOCAL_PREFIX}TemplateToSubject1GenericAffine.mat \
-          -t ${OUTPUT_LOCAL_PREFIX}TemplateToSubject0Warp.nii.gz \
-          -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}TemplateToSubject1GenericAffine.mat \
-          -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}TemplateToSubject0Warp.nii.gz
+        if [[ ! -f ${OUTPUT_LOCAL_PREFIX}SubjectToGroupTemplateWarp.nii.gz ]];
+          then
+            logCmd ${ANTSPATH}/antsApplyTransforms \
+              -d ${DIMENSION} \
+              -r ${REGISTRATION_TEMPLATE} \
+              -o [${OUTPUT_LOCAL_PREFIX}SubjectToGroupTemplateWarp.nii.gz,1] \
+              -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}SubjectToTemplate1Warp.nii.gz \
+              -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}SubjectToTemplate0GenericAffine.mat \
+              -t ${OUTPUT_LOCAL_PREFIX}SubjectToTemplate1Warp.nii.gz \
+              -t ${OUTPUT_LOCAL_PREFIX}SubjectToTemplate0GenericAffine.mat
+          fi
+
+        if [[ ! -f ${OUTPUT_LOCAL_PREFIX}GroupTemplateToSubjectWarp.nii.gz ]];
+          then
+            logCmd ${ANTSPATH}/antsApplyTransforms \
+              -d ${DIMENSION} \
+              -r ${ANATOMICAL_REFERENCE_IMAGE} \
+              -o [${OUTPUT_LOCAL_PREFIX}GroupTemplateToSubjectWarp.nii.gz,1] \
+              -t ${OUTPUT_LOCAL_PREFIX}TemplateToSubject1GenericAffine.mat \
+              -t ${OUTPUT_LOCAL_PREFIX}TemplateToSubject0Warp.nii.gz \
+              -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}TemplateToSubject1GenericAffine.mat \
+              -t ${SINGLE_SUBJECT_ANTSCT_PREFIX}TemplateToSubject0Warp.nii.gz
+          fi
 
         if [[ -f ${CORTICAL_LABEL_IMAGE} ]];
           then
@@ -957,17 +1047,20 @@ for (( i=0; i < ${#ANATOMICAL_IMAGES[@]}; i+=$NUMBER_OF_MODALITIES ))
             SUBJECT_TMP=${OUTPUT_LOCAL_PREFIX}Tmp.${OUTPUT_SUFFIX}
             SUBJECT_STATS=${OUTPUT_LOCAL_PREFIX}LabelThickness.csv
 
-            logCmd ${ANTSPATH}/antsApplyTransforms \
-              -d ${DIMENSION} \
-              -i ${CORTICAL_LABEL_IMAGE} \
-              -r ${ANATOMICAL_REFERENCE_IMAGE} \
-              -o ${SUBJECT_CORTICAL_LABELS} \
-              -n MultiLabel \
-              -t ${OUTPUT_LOCAL_PREFIX}GroupTemplateToSubjectWarp.nii.gz
+            if [[ ! -f ${SUBJECT_CORTICAL_LABELS} ]];
+              then
+                logCmd ${ANTSPATH}/antsApplyTransforms \
+                  -d ${DIMENSION} \
+                  -i ${CORTICAL_LABEL_IMAGE} \
+                  -r ${ANATOMICAL_REFERENCE_IMAGE} \
+                  -o ${SUBJECT_CORTICAL_LABELS} \
+                  -n MultiLabel \
+                  -t ${OUTPUT_LOCAL_PREFIX}GroupTemplateToSubjectWarp.nii.gz
 
-            logCmd ${ANTSPATH}/ThresholdImage ${DIMENSION} ${OUTPUT_LOCAL_PREFIX}BrainSegmentation.${OUTPUT_SUFFIX} ${SUBJECT_TMP} 2 2 1 0
-            logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${SUBJECT_CORTICAL_LABELS} m ${SUBJECT_TMP} ${SUBJECT_CORTICAL_LABELS}
-            logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${SUBJECT_STATS} LabelStats ${SUBJECT_CORTICAL_LABELS} ${SUBJECT_CORTICAL_THICKNESS}
+                logCmd ${ANTSPATH}/ThresholdImage ${DIMENSION} ${OUTPUT_LOCAL_PREFIX}BrainSegmentation.${OUTPUT_SUFFIX} ${SUBJECT_TMP} 2 2 1 0
+                logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${SUBJECT_CORTICAL_LABELS} m ${SUBJECT_TMP} ${SUBJECT_CORTICAL_LABELS}
+                logCmd ${ANTSPATH}/ImageMath ${DIMENSION} ${SUBJECT_STATS} LabelStats ${SUBJECT_CORTICAL_LABELS} ${SUBJECT_CORTICAL_THICKNESS}
+              fi
 
             logCmd rm -f $SUBJECT_TMP
           fi
