@@ -1,14 +1,10 @@
 /*=========================================================================
 
   Program:   Advanced Normalization Tools
-  Module:    $RCSfile: antsSCCANObject.h,v $
-  Language:  C++
-  Date:      $Date: $
-  Version:   $Revision: $
 
   Copyright (c) ConsortiumOfANTS. All rights reserved.
   See accompanying COPYING.txt or
-  http://sourceforge.net/projects/advants/files/ANTS/ANTSCopyright.txt
+  https://github.com/stnava/ANTs/blob/master/ANTSCopyright.txt
   for details.
 
   This software is distributed WITHOUT ANY WARRANTY; without even
@@ -274,6 +270,7 @@ public:
   }
 
   itkSetMacro( Covering, unsigned int );
+  itkSetMacro( GetSmall, bool );
   itkSetMacro( UseL1, bool );
   itkSetMacro( GradStep, RealType );
   itkSetMacro( FractionNonZeroR, RealType );
@@ -457,7 +454,7 @@ public:
     MatrixType cov = this->CovarianceMatrix(p, reg);
     MatrixType invcov = this->PseudoInverse( cov, true );
     bool       debug = false;
-    if( debug )
+    if( ( ! this->m_Silent )  &&  ( debug ) )
       {
       std::cout << " cov " << std::endl;   std::cout << cov << std::endl;
       std::cout << " invcov " << std::endl;   std::cout << invcov << std::endl;
@@ -525,7 +522,7 @@ public:
 
   MatrixType PartialOutZ( MatrixType /*X*/, MatrixType /*Y*/, MatrixType /*Z*/ )
   {
-    std::cout << "ERROR:  This function not yet implemented." << std::endl;
+    if ( ! this->m_Silent )  std::cout << "ERROR:  This function not yet implemented." << std::endl;
     /** compute the effect of Z and store it for later use */
   }
 
@@ -608,8 +605,8 @@ public:
     // std::cout << p.size() <<v.size() <<std::endl;
     if( p.size() != v.size() )
       {
-      std::cout << "FastOuterProductVectorMultiplication Usage Error " << std::endl;
-      std::cout << "Size 1: " << p.size() << "Size 2: " << v.size() << std::endl;
+      if ( ! this->m_Silent )  std::cout << "FastOuterProductVectorMultiplication Usage Error " << std::endl;
+      if ( ! this->m_Silent )  std::cout << "Size 1: " << p.size() << "Size 2: " << v.size() << std::endl;
       return v;
       }
     RealType   ip = inner_product( p, v );
@@ -991,7 +988,11 @@ protected:
   {
     if( x_k1.size() != refvec.size() )
       {
-      std::cout << " sizes dont match " << std::endl; std::exception();
+      if ( ! this->m_Silent )
+        {
+        std::cout << " sizes dont match " << std::endl;
+        }
+      std::exception();
       }
     for( unsigned int i = 0; i < x_k1.size(); i++ )
       {
@@ -1174,15 +1175,15 @@ protected:
   {
     if( this->m_MaskImageP && this->m_MaskImageQ && this->m_MaskImageR )
       {
-      std::cout << " 3 matrices " << std::endl;
+      if ( ! this->m_Silent )  std::cout << " 3 matrices " << std::endl;
       }
     else if( this->m_MaskImageP && this->m_MaskImageQ  )
       {
-      std::cout << " 2 matrices " << std::endl;
+      if ( ! this->m_Silent )  std::cout << " 2 matrices " << std::endl;
       }
     else
       {
-      std::cout << " fewer than 2 matrices " << std::endl;
+      if ( ! this->m_Silent )  std::cout << " fewer than 2 matrices " << std::endl;
       }
   }
 
@@ -1288,6 +1289,7 @@ private:
    *     rather than the default update      : if ( beta > thresh )  beta <- beta  */
   unsigned int     m_Covering;
   unsigned int     m_VecToMaskSize;
+  bool     m_GetSmall;
   bool     m_UseL1;
   bool     m_AlreadyWhitened;
   bool     m_SpecializationForHBM2011;
@@ -1309,6 +1311,8 @@ private:
   vnl_diag_matrix<TRealType> m_PreC; // preconditioning
   RealType                   m_GSBestSol;
   RealType                   m_GradStep;
+  RealType                   m_GradStepP;
+  RealType                   m_GradStepQ;
   RealType                   m_PriorWeight;
 };
 } // namespace ants
